
/* SCHEME->C */

#include <objects.h>

void lap__init();
DEFSTATICTSCP( log_3f_v );
DEFSTATICTSCP( sc_2dicode_v );
DEFSTATICTSCP( set_2did_2dalias_21_v );
DEFSTATICTSCP( set_2did_2dgotos_21_v );
DEFSTATICTSCP( id_2dgotos_v );
DEFSTATICTSCP( free_2ddisplay_v );
DEFSTATICTSCP( report_2derror_v );
DEFSTATICTSCP( pretty_2dprint_2d_24tree_v );
DEFSTATICTSCP( id_2dalias_v );
DEFSTATICTSCP( sc_2dstack_2dtrace_v );
DEFSTATICTSCP( vname_v );
DEFSTATICTSCP( id_2duse_v );
DEFSTATICTSCP( char_2d_3edl_v );
DEFSTATICTSCP( set_2dwrite_2dcount_21_v );
DEFSTATICTSCP( string_2ddowncase_v );
DEFSTATICTSCP( set_2did_2dvname_21_v );
DEFSTATICTSCP( set_2did_2duse_21_v );
DEFSTATICTSCP( c3433 );
DEFSTATICTSCP( t3604 );
DEFSTATICTSCP( t3605 );
DEFSTATICTSCP( t3606 );
DEFSTATICTSCP( t3607 );
DEFSTATICTSCP( t3608 );
DEFSTATICTSCP( t3609 );
DEFSTATICTSCP( t3610 );
DEFSTATICTSCP( t3611 );
DEFSTATICTSCP( t3612 );
DEFSTATICTSCP( t3613 );
DEFSTATICTSCP( t3614 );
DEFSTATICTSCP( t3615 );
DEFSTATICTSCP( t3616 );
DEFSTATICTSCP( t3617 );
DEFSTATICTSCP( t3618 );
DEFSTATICTSCP( t3619 );
DEFSTATICTSCP( t3620 );
DEFSTATICTSCP( t3621 );
DEFSTATICTSCP( t3622 );
DEFSTATICTSCP( t3623 );
DEFSTATICTSCP( t3624 );
DEFSTATICTSCP( t3625 );
DEFSTATICTSCP( t3626 );
DEFSTATICTSCP( t3627 );
DEFSTATICTSCP( t3628 );
DEFSTATICTSCP( t3629 );
DEFSTATICTSCP( t3630 );
DEFSTATICTSCP( t3631 );
DEFSTATICTSCP( t3632 );
DEFSTATICTSCP( t3633 );
DEFSTATICTSCP( t3634 );
DEFSTATICTSCP( t3635 );
DEFSTATICTSCP( t3636 );
DEFSTATICTSCP( t3637 );
DEFSTATICTSCP( t3638 );
DEFSTATICTSCP( t3639 );
DEFSTATICTSCP( t3640 );
DEFSTATICTSCP( t3641 );
DEFSTATICTSCP( t3642 );
DEFSTATICTSCP( t3643 );
DEFSTATICTSCP( t3644 );
DEFSTATICTSCP( t3645 );
DEFSTATICTSCP( t3646 );
DEFSTATICTSCP( t3647 );
DEFSTATICTSCP( t3648 );
DEFSTATICTSCP( t3649 );
DEFSTATICTSCP( t3650 );
DEFSTATICTSCP( t3651 );
DEFSTATICTSCP( t3652 );
DEFSTATICTSCP( t3653 );
DEFSTATICTSCP( t3654 );
DEFSTATICTSCP( t3655 );
DEFSTATICTSCP( t3656 );
DEFSTATICTSCP( t3657 );
DEFSTATICTSCP( t3658 );
DEFSTATICTSCP( t3659 );
DEFSTATICTSCP( t3660 );
DEFSTATICTSCP( t3661 );
DEFSTATICTSCP( t3662 );
DEFSTATICTSCP( t3663 );
DEFSTATICTSCP( t3664 );
DEFSTATICTSCP( t3665 );
DEFSTATICTSCP( t3666 );
DEFSTATICTSCP( t3667 );
DEFSTATICTSCP( t3668 );
DEFSTATICTSCP( t3669 );
DEFSTATICTSCP( t3670 );
DEFSTATICTSCP( t3671 );
DEFSTATICTSCP( t3672 );
DEFSTATICTSCP( t3673 );
DEFSTATICTSCP( t3674 );
DEFSTATICTSCP( t3675 );
DEFSTATICTSCP( t3676 );
DEFSTATICTSCP( t3677 );
DEFSTATICTSCP( t3678 );
DEFSTATICTSCP( t3679 );
DEFSTATICTSCP( t3680 );
DEFSTATICTSCP( t3681 );
DEFSTATICTSCP( t3682 );
DEFSTATICTSCP( t3683 );
DEFSTATICTSCP( t3684 );
DEFSTATICTSCP( t3685 );
DEFSTATICTSCP( t3686 );
DEFSTATICTSCP( t3687 );
DEFSTATICTSCP( t3688 );
DEFSTATICTSCP( t3689 );
DEFSTATICTSCP( t3690 );
DEFSTATICTSCP( t3691 );
DEFSTATICTSCP( t3692 );
DEFSTATICTSCP( t3693 );
DEFSTATICTSCP( t3694 );
DEFSTATICTSCP( t3695 );
DEFSTATICTSCP( t3696 );
DEFSTATICTSCP( t3697 );
DEFSTATICTSCP( t3698 );
DEFSTATICTSCP( t3699 );
DEFSTATICTSCP( t3700 );
DEFSTATICTSCP( t3701 );
DEFSTATICTSCP( t3702 );
DEFSTATICTSCP( t3703 );
DEFSTATICTSCP( t3704 );
DEFSTATICTSCP( t3705 );
DEFSTATICTSCP( t3706 );
DEFSTATICTSCP( t3707 );
DEFSTATICTSCP( t3708 );
DEFSTATICTSCP( t3709 );
DEFSTATICTSCP( t3710 );
DEFSTATICTSCP( t3711 );
DEFSTATICTSCP( t3712 );
DEFSTATICTSCP( t3713 );
DEFSTATICTSCP( t3714 );
DEFSTATICTSCP( t3715 );
DEFSTATICTSCP( t3716 );
DEFSTATICTSCP( t3717 );
DEFSTATICTSCP( t3718 );
DEFSTATICTSCP( t3719 );
DEFSTATICTSCP( t3720 );
DEFSTATICTSCP( t3721 );
DEFSTATICTSCP( t3722 );
DEFSTATICTSCP( t3723 );
DEFSTATICTSCP( t3724 );
DEFSTATICTSCP( t3725 );
DEFSTATICTSCP( t3726 );
DEFSTATICTSCP( t3727 );
DEFSTATICTSCP( t3728 );
DEFSTATICTSCP( t3729 );
DEFSTATICTSCP( t3730 );
DEFSTATICTSCP( t3731 );
DEFSTATICTSCP( t3732 );
DEFSTATICTSCP( t3733 );
DEFSTATICTSCP( t3734 );
DEFSTATICTSCP( t3735 );
DEFSTATICTSCP( t3736 );
DEFSTATICTSCP( t3737 );
DEFSTATICTSCP( t3738 );
DEFSTATICTSCP( t3739 );
DEFSTATICTSCP( t3740 );
DEFSTATICTSCP( t3741 );
DEFSTATICTSCP( t3742 );
DEFSTATICTSCP( t3743 );
DEFSTATICTSCP( t3744 );
DEFSTATICTSCP( t3745 );
DEFSTATICTSCP( t3746 );
DEFSTATICTSCP( t3747 );
DEFSTATICTSCP( t3748 );
DEFSTATICTSCP( t3749 );
DEFSTATICTSCP( t3750 );
DEFSTATICTSCP( t3751 );
DEFSTATICTSCP( t3752 );
DEFSTATICTSCP( t3753 );
DEFSTATICTSCP( t3754 );
DEFSTATICTSCP( t3755 );
DEFSTATICTSCP( t3756 );
DEFSTATICTSCP( t3757 );
DEFSTATICTSCP( t3758 );
DEFSTATICTSCP( t3759 );
DEFSTATICTSCP( t3760 );
DEFSTATICTSCP( t3761 );
DEFSTATICTSCP( t3762 );
DEFSTATICTSCP( t3763 );
DEFSTATICTSCP( t3764 );
DEFSTATICTSCP( t3765 );
DEFSTATICTSCP( t3766 );
DEFSTATICTSCP( t3767 );
DEFSTATICTSCP( t3768 );
DEFSTATICTSCP( t3769 );
DEFSTATICTSCP( t3770 );
DEFSTATICTSCP( t3771 );
DEFSTATICTSCP( t3772 );
DEFSTATICTSCP( t3773 );
DEFSTATICTSCP( t3774 );
DEFSTATICTSCP( t3775 );
DEFSTATICTSCP( t3776 );
DEFSTATICTSCP( t3777 );
DEFSTATICTSCP( t3778 );
DEFSTATICTSCP( t3779 );
DEFSTATICTSCP( t3780 );
DEFSTATICTSCP( t3781 );
DEFSTATICTSCP( t3782 );
DEFSTATICTSCP( t3783 );
DEFSTATICTSCP( t3784 );
DEFSTATICTSCP( t3785 );
DEFSTATICTSCP( t3786 );
DEFSTATICTSCP( t3787 );
DEFSTATICTSCP( t3788 );
DEFSTATICTSCP( t3789 );
DEFSTATICTSCP( t3790 );
DEFSTATICTSCP( t3791 );
DEFSTATICTSCP( t3792 );
DEFSTATICTSCP( t3793 );
DEFSTATICTSCP( t3794 );
DEFSTATICTSCP( t3795 );
DEFSTATICTSCP( t3796 );
DEFSTATICTSCP( t3797 );
DEFSTATICTSCP( t3798 );
DEFSTATICTSCP( t3799 );
DEFSTATICTSCP( t3800 );
DEFSTATICTSCP( t3801 );
DEFSTATICTSCP( t3802 );
DEFSTATICTSCP( t3803 );
DEFSTATICTSCP( t3804 );
DEFSTATICTSCP( t3805 );
DEFSTATICTSCP( t3806 );
DEFSTATICTSCP( t3807 );
DEFSTATICTSCP( t3808 );
DEFSTATICTSCP( t3809 );
DEFSTATICTSCP( t3810 );
DEFSTATICTSCP( t3811 );
DEFSTATICTSCP( t3812 );
DEFSTATICTSCP( t3813 );
DEFSTATICTSCP( t3814 );
DEFSTATICTSCP( t3815 );
DEFSTATICTSCP( t3816 );
DEFSTATICTSCP( t3817 );
DEFSTATICTSCP( t3818 );
DEFSTATICTSCP( t3819 );
DEFSTATICTSCP( t3820 );
DEFSTATICTSCP( t3821 );
DEFSTATICTSCP( t3822 );
DEFSTATICTSCP( t3823 );
DEFSTATICTSCP( t3824 );
DEFSTATICTSCP( t3825 );
DEFSTATICTSCP( t3826 );
DEFSTATICTSCP( t3827 );
DEFSTATICTSCP( t3828 );
DEFSTATICTSCP( t3829 );
DEFSTATICTSCP( t3830 );
DEFSTATICTSCP( t3831 );
DEFSTATICTSCP( t3832 );
DEFSTATICTSCP( t3833 );
DEFSTATICTSCP( t3834 );
DEFSTATICTSCP( t3835 );
DEFSTATICTSCP( t3836 );
DEFSTATICTSCP( t3837 );
DEFSTATICTSCP( t3838 );
DEFSTATICTSCP( t3839 );
DEFSTATICTSCP( t3840 );
DEFSTATICTSCP( t3841 );
DEFSTATICTSCP( t3842 );
DEFSTATICTSCP( t3843 );
DEFSTATICTSCP( t3844 );
DEFSTATICTSCP( t3845 );
DEFSTATICTSCP( t3846 );
DEFSTATICTSCP( t3847 );
DEFSTATICTSCP( t3848 );
DEFSTATICTSCP( t3849 );
DEFSTATICTSCP( t3850 );
DEFSTATICTSCP( t3851 );
DEFSTATICTSCP( t3852 );
DEFSTATICTSCP( t3853 );
DEFSTATICTSCP( t3854 );
DEFSTATICTSCP( t3855 );
DEFSTATICTSCP( t3856 );
DEFSTATICTSCP( t3857 );
DEFSTATICTSCP( t3858 );
DEFSTATICTSCP( t3859 );
DEFSTATICTSCP( t3860 );
DEFSTATICTSCP( t3861 );
DEFSTATICTSCP( t3862 );
DEFSTATICTSCP( t3863 );
DEFSTATICTSCP( t3864 );
DEFSTATICTSCP( t3865 );
DEFSTATICTSCP( t3866 );
DEFSTATICTSCP( t3867 );
DEFSTATICTSCP( t3868 );
DEFSTATICTSCP( t3869 );
DEFSTATICTSCP( t3870 );
DEFSTATICTSCP( t3871 );
DEFSTATICTSCP( t3872 );
DEFSTATICTSCP( t3873 );
DEFSTATICTSCP( t3874 );
DEFSTATICTSCP( t3875 );
DEFSTATICTSCP( t3876 );
DEFSTATICTSCP( t3877 );
DEFSTATICTSCP( t3878 );
DEFSTATICTSCP( t3879 );
DEFSTATICTSCP( t3880 );
DEFSTATICTSCP( t3881 );
DEFSTATICTSCP( t3882 );
DEFSTATICTSCP( t3883 );
DEFSTATICTSCP( t3884 );
DEFSTATICTSCP( t3885 );
DEFSTATICTSCP( t3886 );
DEFSTATICTSCP( t3887 );
DEFSTATICTSCP( t3888 );
DEFSTATICTSCP( t3889 );
DEFSTATICTSCP( t3890 );
DEFSTATICTSCP( t3891 );
DEFSTATICTSCP( t3892 );
DEFSTATICTSCP( t3893 );
DEFSTATICTSCP( t3894 );
DEFSTATICTSCP( t3895 );
DEFSTATICTSCP( t3896 );
DEFSTATICTSCP( t3897 );
DEFSTATICTSCP( t3898 );
DEFSTATICTSCP( t3899 );
DEFSTATICTSCP( t3900 );
DEFSTATICTSCP( t3901 );
DEFSTATICTSCP( t3902 );
DEFSTATICTSCP( t3903 );
DEFSTATICTSCP( t3904 );
DEFSTATICTSCP( t3905 );
DEFSTATICTSCP( c3432 );
DEFCSTRING( t3906, "Argument is not a SYMBOL: ~s" );
DEFSTATICTSCP( c3404 );
DEFSTATICTSCP( c3403 );
DEFCSTRING( t3907, "~a.." );
DEFSTATICTSCP( c3338 );
DEFCSTRING( t3908, "Argument is not a STRING: ~s" );
DEFSTATICTSCP( c3337 );
DEFSTATICTSCP( c3336 );
DEFCSTRING( t3909, ", " );
DEFSTATICTSCP( c3287 );
DEFSTATICTSCP( c3245 );
DEFSTATICTSCP( c3233 );
DEFCSTRING( t3910, "Argument(s) not CHAR: ~s ~s" );
DEFSTATICTSCP( c3225 );
DEFSTATICTSCP( c3224 );
DEFSTATICTSCP( c3181 );
DEFSTATICTSCP( t3911 );
DEFSTATICTSCP( t3912 );
DEFSTATICTSCP( t3913 );
DEFSTATICTSCP( t3914 );
DEFSTATICTSCP( t3915 );
DEFSTATICTSCP( t3916 );
DEFSTATICTSCP( t3917 );
DEFSTATICTSCP( t3918 );
DEFCSTRING( t3919, "~a( " );
DEFSTATICTSCP( c3164 );
DEFCSTRING( t3920, " )" );
DEFSTATICTSCP( c3153 );
DEFCSTRING( t3921, "( " );
DEFSTATICTSCP( c3148 );
DEFSTATICTSCP( c3122 );
DEFSTATICTSCP( c3111 );
DEFSTATICTSCP( c3090 );
DEFSTATICTSCP( c3042 );
DEFSTATICTSCP( t3922 );
DEFSTATICTSCP( c3034 );
DEFCSTRING( t3923, "PPLAP looked up a symbol:" );
DEFSTATICTSCP( c3026 );
DEFCSTRING( t3924, "POP-TOS compiler error" );
DEFSTATICTSCP( c2989 );
DEFCSTRING( t3925, "~a:~%" );
DEFSTATICTSCP( c2940 );
DEFCSTRING( t3926, ";" );
DEFSTATICTSCP( c2899 );
DEFCSTRING( t3927, "        TSCP  " );
DEFSTATICTSCP( c2888 );
DEFCSTRING( t3928, "TSCP  " );
DEFSTATICTSCP( c2872 );
DEFCSTRING( t3929, "~aTSCP  SDVAL;~%" );
DEFSTATICTSCP( c2866 );
DEFCSTRING( t3930, "~aTSCP  SD~a = DISPLAY( ~a );~%" );
DEFSTATICTSCP( c2849 );
DEFCSTRING( t3931, "Argument not a PAIR: ~s" );
DEFSTATICTSCP( c2820 );
DEFSTATICTSCP( c2819 );
DEFCSTRING( t3932, "~aTSCP  " );
DEFSTATICTSCP( c2783 );
DEFCSTRING( t3933, " )  " );
DEFSTATICTSCP( c2770 );
DEFCSTRING( t3934, "~%~a   " );
DEFSTATICTSCP( c2769 );
DEFCSTRING( t3935, "~aif  ( " );
DEFSTATICTSCP( c2745 );
DEFCSTRING( t3936, "PPLAP compiler error" );
DEFSTATICTSCP( c2731 );
DEFSTATICTSCP( c2728 );
DEFCSTRING( t3938, "SDVAL" );
DEFSTATICTSCP( t3937 );
DEFCSTRING( t3939, "POPSTACKTRACE" );
DEFSTATICTSCP( c2717 );
DEFCSTRING( t3940, "return" );
DEFSTATICTSCP( c2716 );
DEFCSTRING( t3941, "~aDISPLAY( ~a ) = SD~a;~%" );
DEFSTATICTSCP( c2706 );
DEFCSTRING( t3942, "~aSDVAL = " );
DEFSTATICTSCP( c2692 );
DEFCSTRING( t3943, "void" );
DEFSTATICTSCP( c2690 );
DEFCSTRING( t3944, " = " );
DEFSTATICTSCP( c2687 );
DEFCSTRING( t3945, ";~%" );
DEFSTATICTSCP( c2664 );
DEFSTATICTSCP( c2652 );
DEFSTATICTSCP( c2648 );
DEFSTATICTSCP( c2644 );
DEFSTATICTSCP( c2637 );
DEFCSTRING( t3946, "~aGOBACK( ~a );~%" );
DEFSTATICTSCP( c2607 );
DEFCSTRING( t3947, "~agoto ~a;~%" );
DEFSTATICTSCP( c2606 );
DEFSTATICTSCP( c2563 );
DEFSTATICTSCP( c2546 );
DEFCSTRING( t3948, "Procedure required >= 300 temporary variables" );
DEFSTATICTSCP( c2545 );
DEFSTATICTSCP( c2518 );
DEFSTATICTSCP( c2407 );
DEFSTATICTSCP( c2354 );
DEFSTATICTSCP( c2213 );
DEFSTATICTSCP( t3949 );
DEFSTATICTSCP( c2207 );
DEFSTATICTSCP( c2185 );
DEFSTATICTSCP( c2143 );
DEFSTATICTSCP( c2132 );
DEFSTATICTSCP( c2111 );
DEFSTATICTSCP( c2100 );
DEFCSTRING( t3950, " */~%" );
DEFSTATICTSCP( c2084 );
DEFCSTRING( t3951, " ~A~%  =>" );
DEFSTATICTSCP( c2053 );
DEFCSTRING( t3952, " ~A" );
DEFSTATICTSCP( c2032 );
DEFCSTRING( t3953, "/* " );
DEFSTATICTSCP( c2020 );
DEFSTATICTSCP( c2016 );

static void  init_constants()
{
        TSCP  X1;

        log_3f_v = STRINGTOSYMBOL( CSTRING_TSCP( "LOG?" ) );
        CONSTANTEXP( ADR( log_3f_v ) );
        sc_2dicode_v = STRINGTOSYMBOL( CSTRING_TSCP( "SC-ICODE" ) );
        CONSTANTEXP( ADR( sc_2dicode_v ) );
        set_2did_2dalias_21_v = STRINGTOSYMBOL( CSTRING_TSCP( "SET-ID-ALIAS!\
" ) );
        CONSTANTEXP( ADR( set_2did_2dalias_21_v ) );
        set_2did_2dgotos_21_v = STRINGTOSYMBOL( CSTRING_TSCP( "SET-ID-GOTOS!\
" ) );
        CONSTANTEXP( ADR( set_2did_2dgotos_21_v ) );
        id_2dgotos_v = STRINGTOSYMBOL( CSTRING_TSCP( "ID-GOTOS" ) );
        CONSTANTEXP( ADR( id_2dgotos_v ) );
        free_2ddisplay_v = STRINGTOSYMBOL( CSTRING_TSCP( "FREE-DISPLAY" ) );
        CONSTANTEXP( ADR( free_2ddisplay_v ) );
        report_2derror_v = STRINGTOSYMBOL( CSTRING_TSCP( "REPORT-ERROR" ) );
        CONSTANTEXP( ADR( report_2derror_v ) );
        pretty_2dprint_2d_24tree_v = STRINGTOSYMBOL( CSTRING_TSCP( "PRETTY-P\
RINT-$TREE" ) );
        CONSTANTEXP( ADR( pretty_2dprint_2d_24tree_v ) );
        id_2dalias_v = STRINGTOSYMBOL( CSTRING_TSCP( "ID-ALIAS" ) );
        CONSTANTEXP( ADR( id_2dalias_v ) );
        sc_2dstack_2dtrace_v = STRINGTOSYMBOL( CSTRING_TSCP( "SC-STACK-TRACE\
" ) );
        CONSTANTEXP( ADR( sc_2dstack_2dtrace_v ) );
        vname_v = STRINGTOSYMBOL( CSTRING_TSCP( "VNAME" ) );
        CONSTANTEXP( ADR( vname_v ) );
        id_2duse_v = STRINGTOSYMBOL( CSTRING_TSCP( "ID-USE" ) );
        CONSTANTEXP( ADR( id_2duse_v ) );
        char_2d_3edl_v = STRINGTOSYMBOL( CSTRING_TSCP( "CHAR->DL" ) );
        CONSTANTEXP( ADR( char_2d_3edl_v ) );
        set_2dwrite_2dcount_21_v = STRINGTOSYMBOL( CSTRING_TSCP( "SET-WRITE-\
COUNT!" ) );
        CONSTANTEXP( ADR( set_2dwrite_2dcount_21_v ) );
        string_2ddowncase_v = STRINGTOSYMBOL( CSTRING_TSCP( "STRING-DOWNCASE\
" ) );
        CONSTANTEXP( ADR( string_2ddowncase_v ) );
        set_2did_2dvname_21_v = STRINGTOSYMBOL( CSTRING_TSCP( "SET-ID-VNAME!\
" ) );
        CONSTANTEXP( ADR( set_2did_2dvname_21_v ) );
        set_2did_2duse_21_v = STRINGTOSYMBOL( CSTRING_TSCP( "SET-ID-USE!" ) );
        CONSTANTEXP( ADR( set_2did_2duse_21_v ) );
        c3433 = EMPTYLIST;
        t3604 = STRINGTOSYMBOL( CSTRING_TSCP( "RETURN" ) );
        c3433 = CONS( t3604, c3433 );
        t3605 = STRINGTOSYMBOL( CSTRING_TSCP( "NO-VALUE" ) );
        c3433 = CONS( t3605, c3433 );
        t3606 = STRINGTOSYMBOL( CSTRING_TSCP( "TOS" ) );
        c3433 = CONS( t3606, c3433 );
        t3607 = STRINGTOSYMBOL( CSTRING_TSCP( "X299" ) );
        c3433 = CONS( t3607, c3433 );
        t3608 = STRINGTOSYMBOL( CSTRING_TSCP( "X298" ) );
        c3433 = CONS( t3608, c3433 );
        t3609 = STRINGTOSYMBOL( CSTRING_TSCP( "X297" ) );
        c3433 = CONS( t3609, c3433 );
        t3610 = STRINGTOSYMBOL( CSTRING_TSCP( "X296" ) );
        c3433 = CONS( t3610, c3433 );
        t3611 = STRINGTOSYMBOL( CSTRING_TSCP( "X295" ) );
        c3433 = CONS( t3611, c3433 );
        t3612 = STRINGTOSYMBOL( CSTRING_TSCP( "X294" ) );
        c3433 = CONS( t3612, c3433 );
        t3613 = STRINGTOSYMBOL( CSTRING_TSCP( "X293" ) );
        c3433 = CONS( t3613, c3433 );
        t3614 = STRINGTOSYMBOL( CSTRING_TSCP( "X292" ) );
        c3433 = CONS( t3614, c3433 );
        t3615 = STRINGTOSYMBOL( CSTRING_TSCP( "X291" ) );
        c3433 = CONS( t3615, c3433 );
        t3616 = STRINGTOSYMBOL( CSTRING_TSCP( "X290" ) );
        c3433 = CONS( t3616, c3433 );
        t3617 = STRINGTOSYMBOL( CSTRING_TSCP( "X289" ) );
        c3433 = CONS( t3617, c3433 );
        t3618 = STRINGTOSYMBOL( CSTRING_TSCP( "X288" ) );
        c3433 = CONS( t3618, c3433 );
        t3619 = STRINGTOSYMBOL( CSTRING_TSCP( "X287" ) );
        c3433 = CONS( t3619, c3433 );
        t3620 = STRINGTOSYMBOL( CSTRING_TSCP( "X286" ) );
        c3433 = CONS( t3620, c3433 );
        t3621 = STRINGTOSYMBOL( CSTRING_TSCP( "X285" ) );
        c3433 = CONS( t3621, c3433 );
        t3622 = STRINGTOSYMBOL( CSTRING_TSCP( "X284" ) );
        c3433 = CONS( t3622, c3433 );
        t3623 = STRINGTOSYMBOL( CSTRING_TSCP( "X283" ) );
        c3433 = CONS( t3623, c3433 );
        t3624 = STRINGTOSYMBOL( CSTRING_TSCP( "X282" ) );
        c3433 = CONS( t3624, c3433 );
        t3625 = STRINGTOSYMBOL( CSTRING_TSCP( "X281" ) );
        c3433 = CONS( t3625, c3433 );
        t3626 = STRINGTOSYMBOL( CSTRING_TSCP( "X280" ) );
        c3433 = CONS( t3626, c3433 );
        t3627 = STRINGTOSYMBOL( CSTRING_TSCP( "X279" ) );
        c3433 = CONS( t3627, c3433 );
        t3628 = STRINGTOSYMBOL( CSTRING_TSCP( "X278" ) );
        c3433 = CONS( t3628, c3433 );
        t3629 = STRINGTOSYMBOL( CSTRING_TSCP( "X277" ) );
        c3433 = CONS( t3629, c3433 );
        t3630 = STRINGTOSYMBOL( CSTRING_TSCP( "X276" ) );
        c3433 = CONS( t3630, c3433 );
        t3631 = STRINGTOSYMBOL( CSTRING_TSCP( "X275" ) );
        c3433 = CONS( t3631, c3433 );
        t3632 = STRINGTOSYMBOL( CSTRING_TSCP( "X274" ) );
        c3433 = CONS( t3632, c3433 );
        t3633 = STRINGTOSYMBOL( CSTRING_TSCP( "X273" ) );
        c3433 = CONS( t3633, c3433 );
        t3634 = STRINGTOSYMBOL( CSTRING_TSCP( "X272" ) );
        c3433 = CONS( t3634, c3433 );
        t3635 = STRINGTOSYMBOL( CSTRING_TSCP( "X271" ) );
        c3433 = CONS( t3635, c3433 );
        t3636 = STRINGTOSYMBOL( CSTRING_TSCP( "X270" ) );
        c3433 = CONS( t3636, c3433 );
        t3637 = STRINGTOSYMBOL( CSTRING_TSCP( "X269" ) );
        c3433 = CONS( t3637, c3433 );
        t3638 = STRINGTOSYMBOL( CSTRING_TSCP( "X268" ) );
        c3433 = CONS( t3638, c3433 );
        t3639 = STRINGTOSYMBOL( CSTRING_TSCP( "X267" ) );
        c3433 = CONS( t3639, c3433 );
        t3640 = STRINGTOSYMBOL( CSTRING_TSCP( "X266" ) );
        c3433 = CONS( t3640, c3433 );
        t3641 = STRINGTOSYMBOL( CSTRING_TSCP( "X265" ) );
        c3433 = CONS( t3641, c3433 );
        t3642 = STRINGTOSYMBOL( CSTRING_TSCP( "X264" ) );
        c3433 = CONS( t3642, c3433 );
        t3643 = STRINGTOSYMBOL( CSTRING_TSCP( "X263" ) );
        c3433 = CONS( t3643, c3433 );
        t3644 = STRINGTOSYMBOL( CSTRING_TSCP( "X262" ) );
        c3433 = CONS( t3644, c3433 );
        t3645 = STRINGTOSYMBOL( CSTRING_TSCP( "X261" ) );
        c3433 = CONS( t3645, c3433 );
        t3646 = STRINGTOSYMBOL( CSTRING_TSCP( "X260" ) );
        c3433 = CONS( t3646, c3433 );
        t3647 = STRINGTOSYMBOL( CSTRING_TSCP( "X259" ) );
        c3433 = CONS( t3647, c3433 );
        t3648 = STRINGTOSYMBOL( CSTRING_TSCP( "X258" ) );
        c3433 = CONS( t3648, c3433 );
        t3649 = STRINGTOSYMBOL( CSTRING_TSCP( "X257" ) );
        c3433 = CONS( t3649, c3433 );
        t3650 = STRINGTOSYMBOL( CSTRING_TSCP( "X256" ) );
        c3433 = CONS( t3650, c3433 );
        t3651 = STRINGTOSYMBOL( CSTRING_TSCP( "X255" ) );
        c3433 = CONS( t3651, c3433 );
        t3652 = STRINGTOSYMBOL( CSTRING_TSCP( "X254" ) );
        c3433 = CONS( t3652, c3433 );
        t3653 = STRINGTOSYMBOL( CSTRING_TSCP( "X253" ) );
        c3433 = CONS( t3653, c3433 );
        t3654 = STRINGTOSYMBOL( CSTRING_TSCP( "X252" ) );
        c3433 = CONS( t3654, c3433 );
        t3655 = STRINGTOSYMBOL( CSTRING_TSCP( "X251" ) );
        c3433 = CONS( t3655, c3433 );
        t3656 = STRINGTOSYMBOL( CSTRING_TSCP( "X250" ) );
        c3433 = CONS( t3656, c3433 );
        t3657 = STRINGTOSYMBOL( CSTRING_TSCP( "X249" ) );
        c3433 = CONS( t3657, c3433 );
        t3658 = STRINGTOSYMBOL( CSTRING_TSCP( "X248" ) );
        c3433 = CONS( t3658, c3433 );
        t3659 = STRINGTOSYMBOL( CSTRING_TSCP( "X247" ) );
        c3433 = CONS( t3659, c3433 );
        t3660 = STRINGTOSYMBOL( CSTRING_TSCP( "X246" ) );
        c3433 = CONS( t3660, c3433 );
        t3661 = STRINGTOSYMBOL( CSTRING_TSCP( "X245" ) );
        c3433 = CONS( t3661, c3433 );
        t3662 = STRINGTOSYMBOL( CSTRING_TSCP( "X244" ) );
        c3433 = CONS( t3662, c3433 );
        t3663 = STRINGTOSYMBOL( CSTRING_TSCP( "X243" ) );
        c3433 = CONS( t3663, c3433 );
        t3664 = STRINGTOSYMBOL( CSTRING_TSCP( "X242" ) );
        c3433 = CONS( t3664, c3433 );
        t3665 = STRINGTOSYMBOL( CSTRING_TSCP( "X241" ) );
        c3433 = CONS( t3665, c3433 );
        t3666 = STRINGTOSYMBOL( CSTRING_TSCP( "X240" ) );
        c3433 = CONS( t3666, c3433 );
        t3667 = STRINGTOSYMBOL( CSTRING_TSCP( "X239" ) );
        c3433 = CONS( t3667, c3433 );
        t3668 = STRINGTOSYMBOL( CSTRING_TSCP( "X238" ) );
        c3433 = CONS( t3668, c3433 );
        t3669 = STRINGTOSYMBOL( CSTRING_TSCP( "X237" ) );
        c3433 = CONS( t3669, c3433 );
        t3670 = STRINGTOSYMBOL( CSTRING_TSCP( "X236" ) );
        c3433 = CONS( t3670, c3433 );
        t3671 = STRINGTOSYMBOL( CSTRING_TSCP( "X235" ) );
        c3433 = CONS( t3671, c3433 );
        t3672 = STRINGTOSYMBOL( CSTRING_TSCP( "X234" ) );
        c3433 = CONS( t3672, c3433 );
        t3673 = STRINGTOSYMBOL( CSTRING_TSCP( "X233" ) );
        c3433 = CONS( t3673, c3433 );
        t3674 = STRINGTOSYMBOL( CSTRING_TSCP( "X232" ) );
        c3433 = CONS( t3674, c3433 );
        t3675 = STRINGTOSYMBOL( CSTRING_TSCP( "X231" ) );
        c3433 = CONS( t3675, c3433 );
        t3676 = STRINGTOSYMBOL( CSTRING_TSCP( "X230" ) );
        c3433 = CONS( t3676, c3433 );
        t3677 = STRINGTOSYMBOL( CSTRING_TSCP( "X229" ) );
        c3433 = CONS( t3677, c3433 );
        t3678 = STRINGTOSYMBOL( CSTRING_TSCP( "X228" ) );
        c3433 = CONS( t3678, c3433 );
        t3679 = STRINGTOSYMBOL( CSTRING_TSCP( "X227" ) );
        c3433 = CONS( t3679, c3433 );
        t3680 = STRINGTOSYMBOL( CSTRING_TSCP( "X226" ) );
        c3433 = CONS( t3680, c3433 );
        t3681 = STRINGTOSYMBOL( CSTRING_TSCP( "X225" ) );
        c3433 = CONS( t3681, c3433 );
        t3682 = STRINGTOSYMBOL( CSTRING_TSCP( "X224" ) );
        c3433 = CONS( t3682, c3433 );
        t3683 = STRINGTOSYMBOL( CSTRING_TSCP( "X223" ) );
        c3433 = CONS( t3683, c3433 );
        t3684 = STRINGTOSYMBOL( CSTRING_TSCP( "X222" ) );
        c3433 = CONS( t3684, c3433 );
        t3685 = STRINGTOSYMBOL( CSTRING_TSCP( "X221" ) );
        c3433 = CONS( t3685, c3433 );
        t3686 = STRINGTOSYMBOL( CSTRING_TSCP( "X220" ) );
        c3433 = CONS( t3686, c3433 );
        t3687 = STRINGTOSYMBOL( CSTRING_TSCP( "X219" ) );
        c3433 = CONS( t3687, c3433 );
        t3688 = STRINGTOSYMBOL( CSTRING_TSCP( "X218" ) );
        c3433 = CONS( t3688, c3433 );
        t3689 = STRINGTOSYMBOL( CSTRING_TSCP( "X217" ) );
        c3433 = CONS( t3689, c3433 );
        t3690 = STRINGTOSYMBOL( CSTRING_TSCP( "X216" ) );
        c3433 = CONS( t3690, c3433 );
        t3691 = STRINGTOSYMBOL( CSTRING_TSCP( "X215" ) );
        c3433 = CONS( t3691, c3433 );
        t3692 = STRINGTOSYMBOL( CSTRING_TSCP( "X214" ) );
        c3433 = CONS( t3692, c3433 );
        t3693 = STRINGTOSYMBOL( CSTRING_TSCP( "X213" ) );
        c3433 = CONS( t3693, c3433 );
        t3694 = STRINGTOSYMBOL( CSTRING_TSCP( "X212" ) );
        c3433 = CONS( t3694, c3433 );
        t3695 = STRINGTOSYMBOL( CSTRING_TSCP( "X211" ) );
        c3433 = CONS( t3695, c3433 );
        t3696 = STRINGTOSYMBOL( CSTRING_TSCP( "X210" ) );
        c3433 = CONS( t3696, c3433 );
        t3697 = STRINGTOSYMBOL( CSTRING_TSCP( "X209" ) );
        c3433 = CONS( t3697, c3433 );
        t3698 = STRINGTOSYMBOL( CSTRING_TSCP( "X208" ) );
        c3433 = CONS( t3698, c3433 );
        t3699 = STRINGTOSYMBOL( CSTRING_TSCP( "X207" ) );
        c3433 = CONS( t3699, c3433 );
        t3700 = STRINGTOSYMBOL( CSTRING_TSCP( "X206" ) );
        c3433 = CONS( t3700, c3433 );
        t3701 = STRINGTOSYMBOL( CSTRING_TSCP( "X205" ) );
        c3433 = CONS( t3701, c3433 );
        t3702 = STRINGTOSYMBOL( CSTRING_TSCP( "X204" ) );
        c3433 = CONS( t3702, c3433 );
        t3703 = STRINGTOSYMBOL( CSTRING_TSCP( "X203" ) );
        c3433 = CONS( t3703, c3433 );
        t3704 = STRINGTOSYMBOL( CSTRING_TSCP( "X202" ) );
        c3433 = CONS( t3704, c3433 );
        t3705 = STRINGTOSYMBOL( CSTRING_TSCP( "X201" ) );
        c3433 = CONS( t3705, c3433 );
        t3706 = STRINGTOSYMBOL( CSTRING_TSCP( "X200" ) );
        c3433 = CONS( t3706, c3433 );
        t3707 = STRINGTOSYMBOL( CSTRING_TSCP( "X199" ) );
        c3433 = CONS( t3707, c3433 );
        t3708 = STRINGTOSYMBOL( CSTRING_TSCP( "X198" ) );
        c3433 = CONS( t3708, c3433 );
        t3709 = STRINGTOSYMBOL( CSTRING_TSCP( "X197" ) );
        c3433 = CONS( t3709, c3433 );
        t3710 = STRINGTOSYMBOL( CSTRING_TSCP( "X196" ) );
        c3433 = CONS( t3710, c3433 );
        t3711 = STRINGTOSYMBOL( CSTRING_TSCP( "X195" ) );
        c3433 = CONS( t3711, c3433 );
        t3712 = STRINGTOSYMBOL( CSTRING_TSCP( "X194" ) );
        c3433 = CONS( t3712, c3433 );
        t3713 = STRINGTOSYMBOL( CSTRING_TSCP( "X193" ) );
        c3433 = CONS( t3713, c3433 );
        t3714 = STRINGTOSYMBOL( CSTRING_TSCP( "X192" ) );
        c3433 = CONS( t3714, c3433 );
        t3715 = STRINGTOSYMBOL( CSTRING_TSCP( "X191" ) );
        c3433 = CONS( t3715, c3433 );
        t3716 = STRINGTOSYMBOL( CSTRING_TSCP( "X190" ) );
        c3433 = CONS( t3716, c3433 );
        t3717 = STRINGTOSYMBOL( CSTRING_TSCP( "X189" ) );
        c3433 = CONS( t3717, c3433 );
        t3718 = STRINGTOSYMBOL( CSTRING_TSCP( "X188" ) );
        c3433 = CONS( t3718, c3433 );
        t3719 = STRINGTOSYMBOL( CSTRING_TSCP( "X187" ) );
        c3433 = CONS( t3719, c3433 );
        t3720 = STRINGTOSYMBOL( CSTRING_TSCP( "X186" ) );
        c3433 = CONS( t3720, c3433 );
        t3721 = STRINGTOSYMBOL( CSTRING_TSCP( "X185" ) );
        c3433 = CONS( t3721, c3433 );
        t3722 = STRINGTOSYMBOL( CSTRING_TSCP( "X184" ) );
        c3433 = CONS( t3722, c3433 );
        t3723 = STRINGTOSYMBOL( CSTRING_TSCP( "X183" ) );
        c3433 = CONS( t3723, c3433 );
        t3724 = STRINGTOSYMBOL( CSTRING_TSCP( "X182" ) );
        c3433 = CONS( t3724, c3433 );
        t3725 = STRINGTOSYMBOL( CSTRING_TSCP( "X181" ) );
        c3433 = CONS( t3725, c3433 );
        t3726 = STRINGTOSYMBOL( CSTRING_TSCP( "X180" ) );
        c3433 = CONS( t3726, c3433 );
        t3727 = STRINGTOSYMBOL( CSTRING_TSCP( "X179" ) );
        c3433 = CONS( t3727, c3433 );
        t3728 = STRINGTOSYMBOL( CSTRING_TSCP( "X178" ) );
        c3433 = CONS( t3728, c3433 );
        t3729 = STRINGTOSYMBOL( CSTRING_TSCP( "X177" ) );
        c3433 = CONS( t3729, c3433 );
        t3730 = STRINGTOSYMBOL( CSTRING_TSCP( "X176" ) );
        c3433 = CONS( t3730, c3433 );
        t3731 = STRINGTOSYMBOL( CSTRING_TSCP( "X175" ) );
        c3433 = CONS( t3731, c3433 );
        t3732 = STRINGTOSYMBOL( CSTRING_TSCP( "X174" ) );
        c3433 = CONS( t3732, c3433 );
        t3733 = STRINGTOSYMBOL( CSTRING_TSCP( "X173" ) );
        c3433 = CONS( t3733, c3433 );
        t3734 = STRINGTOSYMBOL( CSTRING_TSCP( "X172" ) );
        c3433 = CONS( t3734, c3433 );
        t3735 = STRINGTOSYMBOL( CSTRING_TSCP( "X171" ) );
        c3433 = CONS( t3735, c3433 );
        t3736 = STRINGTOSYMBOL( CSTRING_TSCP( "X170" ) );
        c3433 = CONS( t3736, c3433 );
        t3737 = STRINGTOSYMBOL( CSTRING_TSCP( "X169" ) );
        c3433 = CONS( t3737, c3433 );
        t3738 = STRINGTOSYMBOL( CSTRING_TSCP( "X168" ) );
        c3433 = CONS( t3738, c3433 );
        t3739 = STRINGTOSYMBOL( CSTRING_TSCP( "X167" ) );
        c3433 = CONS( t3739, c3433 );
        t3740 = STRINGTOSYMBOL( CSTRING_TSCP( "X166" ) );
        c3433 = CONS( t3740, c3433 );
        t3741 = STRINGTOSYMBOL( CSTRING_TSCP( "X165" ) );
        c3433 = CONS( t3741, c3433 );
        t3742 = STRINGTOSYMBOL( CSTRING_TSCP( "X164" ) );
        c3433 = CONS( t3742, c3433 );
        t3743 = STRINGTOSYMBOL( CSTRING_TSCP( "X163" ) );
        c3433 = CONS( t3743, c3433 );
        t3744 = STRINGTOSYMBOL( CSTRING_TSCP( "X162" ) );
        c3433 = CONS( t3744, c3433 );
        t3745 = STRINGTOSYMBOL( CSTRING_TSCP( "X161" ) );
        c3433 = CONS( t3745, c3433 );
        t3746 = STRINGTOSYMBOL( CSTRING_TSCP( "X160" ) );
        c3433 = CONS( t3746, c3433 );
        t3747 = STRINGTOSYMBOL( CSTRING_TSCP( "X159" ) );
        c3433 = CONS( t3747, c3433 );
        t3748 = STRINGTOSYMBOL( CSTRING_TSCP( "X158" ) );
        c3433 = CONS( t3748, c3433 );
        t3749 = STRINGTOSYMBOL( CSTRING_TSCP( "X157" ) );
        c3433 = CONS( t3749, c3433 );
        t3750 = STRINGTOSYMBOL( CSTRING_TSCP( "X156" ) );
        c3433 = CONS( t3750, c3433 );
        t3751 = STRINGTOSYMBOL( CSTRING_TSCP( "X155" ) );
        c3433 = CONS( t3751, c3433 );
        t3752 = STRINGTOSYMBOL( CSTRING_TSCP( "X154" ) );
        c3433 = CONS( t3752, c3433 );
        t3753 = STRINGTOSYMBOL( CSTRING_TSCP( "X153" ) );
        c3433 = CONS( t3753, c3433 );
        t3754 = STRINGTOSYMBOL( CSTRING_TSCP( "X152" ) );
        c3433 = CONS( t3754, c3433 );
        t3755 = STRINGTOSYMBOL( CSTRING_TSCP( "X151" ) );
        c3433 = CONS( t3755, c3433 );
        t3756 = STRINGTOSYMBOL( CSTRING_TSCP( "X150" ) );
        c3433 = CONS( t3756, c3433 );
        t3757 = STRINGTOSYMBOL( CSTRING_TSCP( "X149" ) );
        c3433 = CONS( t3757, c3433 );
        t3758 = STRINGTOSYMBOL( CSTRING_TSCP( "X148" ) );
        c3433 = CONS( t3758, c3433 );
        t3759 = STRINGTOSYMBOL( CSTRING_TSCP( "X147" ) );
        c3433 = CONS( t3759, c3433 );
        t3760 = STRINGTOSYMBOL( CSTRING_TSCP( "X146" ) );
        c3433 = CONS( t3760, c3433 );
        t3761 = STRINGTOSYMBOL( CSTRING_TSCP( "X145" ) );
        c3433 = CONS( t3761, c3433 );
        t3762 = STRINGTOSYMBOL( CSTRING_TSCP( "X144" ) );
        c3433 = CONS( t3762, c3433 );
        t3763 = STRINGTOSYMBOL( CSTRING_TSCP( "X143" ) );
        c3433 = CONS( t3763, c3433 );
        t3764 = STRINGTOSYMBOL( CSTRING_TSCP( "X142" ) );
        c3433 = CONS( t3764, c3433 );
        t3765 = STRINGTOSYMBOL( CSTRING_TSCP( "X141" ) );
        c3433 = CONS( t3765, c3433 );
        t3766 = STRINGTOSYMBOL( CSTRING_TSCP( "X140" ) );
        c3433 = CONS( t3766, c3433 );
        t3767 = STRINGTOSYMBOL( CSTRING_TSCP( "X139" ) );
        c3433 = CONS( t3767, c3433 );
        t3768 = STRINGTOSYMBOL( CSTRING_TSCP( "X138" ) );
        c3433 = CONS( t3768, c3433 );
        t3769 = STRINGTOSYMBOL( CSTRING_TSCP( "X137" ) );
        c3433 = CONS( t3769, c3433 );
        t3770 = STRINGTOSYMBOL( CSTRING_TSCP( "X136" ) );
        c3433 = CONS( t3770, c3433 );
        t3771 = STRINGTOSYMBOL( CSTRING_TSCP( "X135" ) );
        c3433 = CONS( t3771, c3433 );
        t3772 = STRINGTOSYMBOL( CSTRING_TSCP( "X134" ) );
        c3433 = CONS( t3772, c3433 );
        t3773 = STRINGTOSYMBOL( CSTRING_TSCP( "X133" ) );
        c3433 = CONS( t3773, c3433 );
        t3774 = STRINGTOSYMBOL( CSTRING_TSCP( "X132" ) );
        c3433 = CONS( t3774, c3433 );
        t3775 = STRINGTOSYMBOL( CSTRING_TSCP( "X131" ) );
        c3433 = CONS( t3775, c3433 );
        t3776 = STRINGTOSYMBOL( CSTRING_TSCP( "X130" ) );
        c3433 = CONS( t3776, c3433 );
        t3777 = STRINGTOSYMBOL( CSTRING_TSCP( "X129" ) );
        c3433 = CONS( t3777, c3433 );
        t3778 = STRINGTOSYMBOL( CSTRING_TSCP( "X128" ) );
        c3433 = CONS( t3778, c3433 );
        t3779 = STRINGTOSYMBOL( CSTRING_TSCP( "X127" ) );
        c3433 = CONS( t3779, c3433 );
        t3780 = STRINGTOSYMBOL( CSTRING_TSCP( "X126" ) );
        c3433 = CONS( t3780, c3433 );
        t3781 = STRINGTOSYMBOL( CSTRING_TSCP( "X125" ) );
        c3433 = CONS( t3781, c3433 );
        t3782 = STRINGTOSYMBOL( CSTRING_TSCP( "X124" ) );
        c3433 = CONS( t3782, c3433 );
        t3783 = STRINGTOSYMBOL( CSTRING_TSCP( "X123" ) );
        c3433 = CONS( t3783, c3433 );
        t3784 = STRINGTOSYMBOL( CSTRING_TSCP( "X122" ) );
        c3433 = CONS( t3784, c3433 );
        t3785 = STRINGTOSYMBOL( CSTRING_TSCP( "X121" ) );
        c3433 = CONS( t3785, c3433 );
        t3786 = STRINGTOSYMBOL( CSTRING_TSCP( "X120" ) );
        c3433 = CONS( t3786, c3433 );
        t3787 = STRINGTOSYMBOL( CSTRING_TSCP( "X119" ) );
        c3433 = CONS( t3787, c3433 );
        t3788 = STRINGTOSYMBOL( CSTRING_TSCP( "X118" ) );
        c3433 = CONS( t3788, c3433 );
        t3789 = STRINGTOSYMBOL( CSTRING_TSCP( "X117" ) );
        c3433 = CONS( t3789, c3433 );
        t3790 = STRINGTOSYMBOL( CSTRING_TSCP( "X116" ) );
        c3433 = CONS( t3790, c3433 );
        t3791 = STRINGTOSYMBOL( CSTRING_TSCP( "X115" ) );
        c3433 = CONS( t3791, c3433 );
        t3792 = STRINGTOSYMBOL( CSTRING_TSCP( "X114" ) );
        c3433 = CONS( t3792, c3433 );
        t3793 = STRINGTOSYMBOL( CSTRING_TSCP( "X113" ) );
        c3433 = CONS( t3793, c3433 );
        t3794 = STRINGTOSYMBOL( CSTRING_TSCP( "X112" ) );
        c3433 = CONS( t3794, c3433 );
        t3795 = STRINGTOSYMBOL( CSTRING_TSCP( "X111" ) );
        c3433 = CONS( t3795, c3433 );
        t3796 = STRINGTOSYMBOL( CSTRING_TSCP( "X110" ) );
        c3433 = CONS( t3796, c3433 );
        t3797 = STRINGTOSYMBOL( CSTRING_TSCP( "X109" ) );
        c3433 = CONS( t3797, c3433 );
        t3798 = STRINGTOSYMBOL( CSTRING_TSCP( "X108" ) );
        c3433 = CONS( t3798, c3433 );
        t3799 = STRINGTOSYMBOL( CSTRING_TSCP( "X107" ) );
        c3433 = CONS( t3799, c3433 );
        t3800 = STRINGTOSYMBOL( CSTRING_TSCP( "X106" ) );
        c3433 = CONS( t3800, c3433 );
        t3801 = STRINGTOSYMBOL( CSTRING_TSCP( "X105" ) );
        c3433 = CONS( t3801, c3433 );
        t3802 = STRINGTOSYMBOL( CSTRING_TSCP( "X104" ) );
        c3433 = CONS( t3802, c3433 );
        t3803 = STRINGTOSYMBOL( CSTRING_TSCP( "X103" ) );
        c3433 = CONS( t3803, c3433 );
        t3804 = STRINGTOSYMBOL( CSTRING_TSCP( "X102" ) );
        c3433 = CONS( t3804, c3433 );
        t3805 = STRINGTOSYMBOL( CSTRING_TSCP( "X101" ) );
        c3433 = CONS( t3805, c3433 );
        t3806 = STRINGTOSYMBOL( CSTRING_TSCP( "X100" ) );
        c3433 = CONS( t3806, c3433 );
        t3807 = STRINGTOSYMBOL( CSTRING_TSCP( "X99" ) );
        c3433 = CONS( t3807, c3433 );
        t3808 = STRINGTOSYMBOL( CSTRING_TSCP( "X98" ) );
        c3433 = CONS( t3808, c3433 );
        t3809 = STRINGTOSYMBOL( CSTRING_TSCP( "X97" ) );
        c3433 = CONS( t3809, c3433 );
        t3810 = STRINGTOSYMBOL( CSTRING_TSCP( "X96" ) );
        c3433 = CONS( t3810, c3433 );
        t3811 = STRINGTOSYMBOL( CSTRING_TSCP( "X95" ) );
        c3433 = CONS( t3811, c3433 );
        t3812 = STRINGTOSYMBOL( CSTRING_TSCP( "X94" ) );
        c3433 = CONS( t3812, c3433 );
        t3813 = STRINGTOSYMBOL( CSTRING_TSCP( "X93" ) );
        c3433 = CONS( t3813, c3433 );
        t3814 = STRINGTOSYMBOL( CSTRING_TSCP( "X92" ) );
        c3433 = CONS( t3814, c3433 );
        t3815 = STRINGTOSYMBOL( CSTRING_TSCP( "X91" ) );
        c3433 = CONS( t3815, c3433 );
        t3816 = STRINGTOSYMBOL( CSTRING_TSCP( "X90" ) );
        c3433 = CONS( t3816, c3433 );
        t3817 = STRINGTOSYMBOL( CSTRING_TSCP( "X89" ) );
        c3433 = CONS( t3817, c3433 );
        t3818 = STRINGTOSYMBOL( CSTRING_TSCP( "X88" ) );
        c3433 = CONS( t3818, c3433 );
        t3819 = STRINGTOSYMBOL( CSTRING_TSCP( "X87" ) );
        c3433 = CONS( t3819, c3433 );
        t3820 = STRINGTOSYMBOL( CSTRING_TSCP( "X86" ) );
        c3433 = CONS( t3820, c3433 );
        t3821 = STRINGTOSYMBOL( CSTRING_TSCP( "X85" ) );
        c3433 = CONS( t3821, c3433 );
        t3822 = STRINGTOSYMBOL( CSTRING_TSCP( "X84" ) );
        c3433 = CONS( t3822, c3433 );
        t3823 = STRINGTOSYMBOL( CSTRING_TSCP( "X83" ) );
        c3433 = CONS( t3823, c3433 );
        t3824 = STRINGTOSYMBOL( CSTRING_TSCP( "X82" ) );
        c3433 = CONS( t3824, c3433 );
        t3825 = STRINGTOSYMBOL( CSTRING_TSCP( "X81" ) );
        c3433 = CONS( t3825, c3433 );
        t3826 = STRINGTOSYMBOL( CSTRING_TSCP( "X80" ) );
        c3433 = CONS( t3826, c3433 );
        t3827 = STRINGTOSYMBOL( CSTRING_TSCP( "X79" ) );
        c3433 = CONS( t3827, c3433 );
        t3828 = STRINGTOSYMBOL( CSTRING_TSCP( "X78" ) );
        c3433 = CONS( t3828, c3433 );
        t3829 = STRINGTOSYMBOL( CSTRING_TSCP( "X77" ) );
        c3433 = CONS( t3829, c3433 );
        t3830 = STRINGTOSYMBOL( CSTRING_TSCP( "X76" ) );
        c3433 = CONS( t3830, c3433 );
        t3831 = STRINGTOSYMBOL( CSTRING_TSCP( "X75" ) );
        c3433 = CONS( t3831, c3433 );
        t3832 = STRINGTOSYMBOL( CSTRING_TSCP( "X74" ) );
        c3433 = CONS( t3832, c3433 );
        t3833 = STRINGTOSYMBOL( CSTRING_TSCP( "X73" ) );
        c3433 = CONS( t3833, c3433 );
        t3834 = STRINGTOSYMBOL( CSTRING_TSCP( "X72" ) );
        c3433 = CONS( t3834, c3433 );
        t3835 = STRINGTOSYMBOL( CSTRING_TSCP( "X71" ) );
        c3433 = CONS( t3835, c3433 );
        t3836 = STRINGTOSYMBOL( CSTRING_TSCP( "X70" ) );
        c3433 = CONS( t3836, c3433 );
        t3837 = STRINGTOSYMBOL( CSTRING_TSCP( "X69" ) );
        c3433 = CONS( t3837, c3433 );
        t3838 = STRINGTOSYMBOL( CSTRING_TSCP( "X68" ) );
        c3433 = CONS( t3838, c3433 );
        t3839 = STRINGTOSYMBOL( CSTRING_TSCP( "X67" ) );
        c3433 = CONS( t3839, c3433 );
        t3840 = STRINGTOSYMBOL( CSTRING_TSCP( "X66" ) );
        c3433 = CONS( t3840, c3433 );
        t3841 = STRINGTOSYMBOL( CSTRING_TSCP( "X65" ) );
        c3433 = CONS( t3841, c3433 );
        t3842 = STRINGTOSYMBOL( CSTRING_TSCP( "X64" ) );
        c3433 = CONS( t3842, c3433 );
        t3843 = STRINGTOSYMBOL( CSTRING_TSCP( "X63" ) );
        c3433 = CONS( t3843, c3433 );
        t3844 = STRINGTOSYMBOL( CSTRING_TSCP( "X62" ) );
        c3433 = CONS( t3844, c3433 );
        t3845 = STRINGTOSYMBOL( CSTRING_TSCP( "X61" ) );
        c3433 = CONS( t3845, c3433 );
        t3846 = STRINGTOSYMBOL( CSTRING_TSCP( "X60" ) );
        c3433 = CONS( t3846, c3433 );
        t3847 = STRINGTOSYMBOL( CSTRING_TSCP( "X59" ) );
        c3433 = CONS( t3847, c3433 );
        t3848 = STRINGTOSYMBOL( CSTRING_TSCP( "X58" ) );
        c3433 = CONS( t3848, c3433 );
        t3849 = STRINGTOSYMBOL( CSTRING_TSCP( "X57" ) );
        c3433 = CONS( t3849, c3433 );
        t3850 = STRINGTOSYMBOL( CSTRING_TSCP( "X56" ) );
        c3433 = CONS( t3850, c3433 );
        t3851 = STRINGTOSYMBOL( CSTRING_TSCP( "X55" ) );
        c3433 = CONS( t3851, c3433 );
        t3852 = STRINGTOSYMBOL( CSTRING_TSCP( "X54" ) );
        c3433 = CONS( t3852, c3433 );
        t3853 = STRINGTOSYMBOL( CSTRING_TSCP( "X53" ) );
        c3433 = CONS( t3853, c3433 );
        t3854 = STRINGTOSYMBOL( CSTRING_TSCP( "X52" ) );
        c3433 = CONS( t3854, c3433 );
        t3855 = STRINGTOSYMBOL( CSTRING_TSCP( "X51" ) );
        c3433 = CONS( t3855, c3433 );
        t3856 = STRINGTOSYMBOL( CSTRING_TSCP( "X50" ) );
        c3433 = CONS( t3856, c3433 );
        t3857 = STRINGTOSYMBOL( CSTRING_TSCP( "X49" ) );
        c3433 = CONS( t3857, c3433 );
        t3858 = STRINGTOSYMBOL( CSTRING_TSCP( "X48" ) );
        c3433 = CONS( t3858, c3433 );
        t3859 = STRINGTOSYMBOL( CSTRING_TSCP( "X47" ) );
        c3433 = CONS( t3859, c3433 );
        t3860 = STRINGTOSYMBOL( CSTRING_TSCP( "X46" ) );
        c3433 = CONS( t3860, c3433 );
        t3861 = STRINGTOSYMBOL( CSTRING_TSCP( "X45" ) );
        c3433 = CONS( t3861, c3433 );
        t3862 = STRINGTOSYMBOL( CSTRING_TSCP( "X44" ) );
        c3433 = CONS( t3862, c3433 );
        t3863 = STRINGTOSYMBOL( CSTRING_TSCP( "X43" ) );
        c3433 = CONS( t3863, c3433 );
        t3864 = STRINGTOSYMBOL( CSTRING_TSCP( "X42" ) );
        c3433 = CONS( t3864, c3433 );
        t3865 = STRINGTOSYMBOL( CSTRING_TSCP( "X41" ) );
        c3433 = CONS( t3865, c3433 );
        t3866 = STRINGTOSYMBOL( CSTRING_TSCP( "X40" ) );
        c3433 = CONS( t3866, c3433 );
        t3867 = STRINGTOSYMBOL( CSTRING_TSCP( "X39" ) );
        c3433 = CONS( t3867, c3433 );
        t3868 = STRINGTOSYMBOL( CSTRING_TSCP( "X38" ) );
        c3433 = CONS( t3868, c3433 );
        t3869 = STRINGTOSYMBOL( CSTRING_TSCP( "X37" ) );
        c3433 = CONS( t3869, c3433 );
        t3870 = STRINGTOSYMBOL( CSTRING_TSCP( "X36" ) );
        c3433 = CONS( t3870, c3433 );
        t3871 = STRINGTOSYMBOL( CSTRING_TSCP( "X35" ) );
        c3433 = CONS( t3871, c3433 );
        t3872 = STRINGTOSYMBOL( CSTRING_TSCP( "X34" ) );
        c3433 = CONS( t3872, c3433 );
        t3873 = STRINGTOSYMBOL( CSTRING_TSCP( "X33" ) );
        c3433 = CONS( t3873, c3433 );
        t3874 = STRINGTOSYMBOL( CSTRING_TSCP( "X32" ) );
        c3433 = CONS( t3874, c3433 );
        t3875 = STRINGTOSYMBOL( CSTRING_TSCP( "X31" ) );
        c3433 = CONS( t3875, c3433 );
        t3876 = STRINGTOSYMBOL( CSTRING_TSCP( "X30" ) );
        c3433 = CONS( t3876, c3433 );
        t3877 = STRINGTOSYMBOL( CSTRING_TSCP( "X29" ) );
        c3433 = CONS( t3877, c3433 );
        t3878 = STRINGTOSYMBOL( CSTRING_TSCP( "X28" ) );
        c3433 = CONS( t3878, c3433 );
        t3879 = STRINGTOSYMBOL( CSTRING_TSCP( "X27" ) );
        c3433 = CONS( t3879, c3433 );
        t3880 = STRINGTOSYMBOL( CSTRING_TSCP( "X26" ) );
        c3433 = CONS( t3880, c3433 );
        t3881 = STRINGTOSYMBOL( CSTRING_TSCP( "X25" ) );
        c3433 = CONS( t3881, c3433 );
        t3882 = STRINGTOSYMBOL( CSTRING_TSCP( "X24" ) );
        c3433 = CONS( t3882, c3433 );
        t3883 = STRINGTOSYMBOL( CSTRING_TSCP( "X23" ) );
        c3433 = CONS( t3883, c3433 );
        t3884 = STRINGTOSYMBOL( CSTRING_TSCP( "X22" ) );
        c3433 = CONS( t3884, c3433 );
        t3885 = STRINGTOSYMBOL( CSTRING_TSCP( "X21" ) );
        c3433 = CONS( t3885, c3433 );
        t3886 = STRINGTOSYMBOL( CSTRING_TSCP( "X20" ) );
        c3433 = CONS( t3886, c3433 );
        t3887 = STRINGTOSYMBOL( CSTRING_TSCP( "X19" ) );
        c3433 = CONS( t3887, c3433 );
        t3888 = STRINGTOSYMBOL( CSTRING_TSCP( "X18" ) );
        c3433 = CONS( t3888, c3433 );
        t3889 = STRINGTOSYMBOL( CSTRING_TSCP( "X17" ) );
        c3433 = CONS( t3889, c3433 );
        t3890 = STRINGTOSYMBOL( CSTRING_TSCP( "X16" ) );
        c3433 = CONS( t3890, c3433 );
        t3891 = STRINGTOSYMBOL( CSTRING_TSCP( "X15" ) );
        c3433 = CONS( t3891, c3433 );
        t3892 = STRINGTOSYMBOL( CSTRING_TSCP( "X14" ) );
        c3433 = CONS( t3892, c3433 );
        t3893 = STRINGTOSYMBOL( CSTRING_TSCP( "X13" ) );
        c3433 = CONS( t3893, c3433 );
        t3894 = STRINGTOSYMBOL( CSTRING_TSCP( "X12" ) );
        c3433 = CONS( t3894, c3433 );
        t3895 = STRINGTOSYMBOL( CSTRING_TSCP( "X11" ) );
        c3433 = CONS( t3895, c3433 );
        t3896 = STRINGTOSYMBOL( CSTRING_TSCP( "X10" ) );
        c3433 = CONS( t3896, c3433 );
        t3897 = STRINGTOSYMBOL( CSTRING_TSCP( "X9" ) );
        c3433 = CONS( t3897, c3433 );
        t3898 = STRINGTOSYMBOL( CSTRING_TSCP( "X8" ) );
        c3433 = CONS( t3898, c3433 );
        t3899 = STRINGTOSYMBOL( CSTRING_TSCP( "X7" ) );
        c3433 = CONS( t3899, c3433 );
        t3900 = STRINGTOSYMBOL( CSTRING_TSCP( "X6" ) );
        c3433 = CONS( t3900, c3433 );
        t3901 = STRINGTOSYMBOL( CSTRING_TSCP( "X5" ) );
        c3433 = CONS( t3901, c3433 );
        t3902 = STRINGTOSYMBOL( CSTRING_TSCP( "X4" ) );
        c3433 = CONS( t3902, c3433 );
        t3903 = STRINGTOSYMBOL( CSTRING_TSCP( "X3" ) );
        c3433 = CONS( t3903, c3433 );
        t3904 = STRINGTOSYMBOL( CSTRING_TSCP( "X2" ) );
        c3433 = CONS( t3904, c3433 );
        t3905 = STRINGTOSYMBOL( CSTRING_TSCP( "X1" ) );
        c3433 = CONS( t3905, c3433 );
        CONSTANTEXP( ADR( c3433 ) );
        c3432 = STRINGTOSYMBOL( CSTRING_TSCP( "$LEXICAL" ) );
        CONSTANTEXP( ADR( c3432 ) );
        c3404 = CSTRING_TSCP( t3906 );
        CONSTANTEXP( ADR( c3404 ) );
        c3403 = STRINGTOSYMBOL( CSTRING_TSCP( "SYMBOL->STRING" ) );
        CONSTANTEXP( ADR( c3403 ) );
        c3338 = CSTRING_TSCP( t3907 );
        CONSTANTEXP( ADR( c3338 ) );
        c3337 = CSTRING_TSCP( t3908 );
        CONSTANTEXP( ADR( c3337 ) );
        c3336 = STRINGTOSYMBOL( CSTRING_TSCP( "STRING-LENGTH" ) );
        CONSTANTEXP( ADR( c3336 ) );
        c3287 = CSTRING_TSCP( t3909 );
        CONSTANTEXP( ADR( c3287 ) );
        c3245 = EMPTYLIST;
        X1 = _TSCP( 23570 );
        X1 = CONS( _TSCP( 23570 ), X1 );
        c3245 = CONS( X1, c3245 );
        X1 = _TSCP( 8722 );
        X1 = CONS( _TSCP( 8722 ), X1 );
        c3245 = CONS( X1, c3245 );
        X1 = _TSCP( 29202 );
        X1 = CONS( _TSCP( 3346 ), X1 );
        c3245 = CONS( X1, c3245 );
        X1 = _TSCP( 26130 );
        X1 = CONS( _TSCP( 3090 ), X1 );
        c3245 = CONS( X1, c3245 );
        X1 = _TSCP( 28178 );
        X1 = CONS( _TSCP( 2578 ), X1 );
        c3245 = CONS( X1, c3245 );
        X1 = _TSCP( 28178 );
        X1 = CONS( _TSCP( 2578 ), X1 );
        c3245 = CONS( X1, c3245 );
        X1 = _TSCP( 29714 );
        X1 = CONS( _TSCP( 2322 ), X1 );
        c3245 = CONS( X1, c3245 );
        CONSTANTEXP( ADR( c3245 ) );
        c3233 = STRINGTOSYMBOL( CSTRING_TSCP( "CHAR>?" ) );
        CONSTANTEXP( ADR( c3233 ) );
        c3225 = CSTRING_TSCP( t3910 );
        CONSTANTEXP( ADR( c3225 ) );
        c3224 = STRINGTOSYMBOL( CSTRING_TSCP( "CHAR<?" ) );
        CONSTANTEXP( ADR( c3224 ) );
        c3181 = EMPTYLIST;
        t3911 = STRINGTOSYMBOL( CSTRING_TSCP( "GT" ) );
        X1 = t3911;
        t3912 = STRINGTOSYMBOL( CSTRING_TSCP( "LTE" ) );
        X1 = CONS( t3912, X1 );
        c3181 = CONS( X1, c3181 );
        X1 = t3912;
        X1 = CONS( t3911, X1 );
        c3181 = CONS( X1, c3181 );
        t3913 = STRINGTOSYMBOL( CSTRING_TSCP( "LT" ) );
        X1 = t3913;
        t3914 = STRINGTOSYMBOL( CSTRING_TSCP( "GTE" ) );
        X1 = CONS( t3914, X1 );
        c3181 = CONS( X1, c3181 );
        X1 = t3914;
        X1 = CONS( t3913, X1 );
        c3181 = CONS( X1, c3181 );
        t3915 = STRINGTOSYMBOL( CSTRING_TSCP( "TRUE" ) );
        X1 = t3915;
        t3916 = STRINGTOSYMBOL( CSTRING_TSCP( "FALSE" ) );
        X1 = CONS( t3916, X1 );
        c3181 = CONS( X1, c3181 );
        X1 = t3916;
        X1 = CONS( t3915, X1 );
        c3181 = CONS( X1, c3181 );
        t3917 = STRINGTOSYMBOL( CSTRING_TSCP( "EQ" ) );
        X1 = t3917;
        t3918 = STRINGTOSYMBOL( CSTRING_TSCP( "NEQ" ) );
        X1 = CONS( t3918, X1 );
        c3181 = CONS( X1, c3181 );
        X1 = t3918;
        X1 = CONS( t3917, X1 );
        c3181 = CONS( X1, c3181 );
        CONSTANTEXP( ADR( c3181 ) );
        c3164 = CSTRING_TSCP( t3919 );
        CONSTANTEXP( ADR( c3164 ) );
        c3153 = CSTRING_TSCP( t3920 );
        CONSTANTEXP( ADR( c3153 ) );
        c3148 = CSTRING_TSCP( t3921 );
        CONSTANTEXP( ADR( c3148 ) );
        c3122 = STRINGTOSYMBOL( CSTRING_TSCP( "FALSE" ) );
        CONSTANTEXP( ADR( c3122 ) );
        c3111 = STRINGTOSYMBOL( CSTRING_TSCP( "BOOLEAN" ) );
        CONSTANTEXP( ADR( c3111 ) );
        c3090 = STRINGTOSYMBOL( CSTRING_TSCP( "TRUE" ) );
        CONSTANTEXP( ADR( c3090 ) );
        c3042 = EMPTYLIST;
        t3922 = STRINGTOSYMBOL( CSTRING_TSCP( "NOT" ) );
        c3042 = CONS( t3922, c3042 );
        c3042 = CONS( c3122, c3042 );
        c3042 = CONS( c3090, c3042 );
        CONSTANTEXP( ADR( c3042 ) );
        c3034 = STRINGTOSYMBOL( CSTRING_TSCP( "CSTRING" ) );
        CONSTANTEXP( ADR( c3034 ) );
        c3026 = CSTRING_TSCP( t3923 );
        CONSTANTEXP( ADR( c3026 ) );
        c2989 = CSTRING_TSCP( t3924 );
        CONSTANTEXP( ADR( c2989 ) );
        c2940 = CSTRING_TSCP( t3925 );
        CONSTANTEXP( ADR( c2940 ) );
        c2899 = CSTRING_TSCP( t3926 );
        CONSTANTEXP( ADR( c2899 ) );
        c2888 = CSTRING_TSCP( t3927 );
        CONSTANTEXP( ADR( c2888 ) );
        c2872 = CSTRING_TSCP( t3928 );
        CONSTANTEXP( ADR( c2872 ) );
        c2866 = CSTRING_TSCP( t3929 );
        CONSTANTEXP( ADR( c2866 ) );
        c2849 = CSTRING_TSCP( t3930 );
        CONSTANTEXP( ADR( c2849 ) );
        c2820 = CSTRING_TSCP( t3931 );
        CONSTANTEXP( ADR( c2820 ) );
        c2819 = STRINGTOSYMBOL( CSTRING_TSCP( "SET-CDR!" ) );
        CONSTANTEXP( ADR( c2819 ) );
        c2783 = CSTRING_TSCP( t3932 );
        CONSTANTEXP( ADR( c2783 ) );
        c2770 = CSTRING_TSCP( t3933 );
        CONSTANTEXP( ADR( c2770 ) );
        c2769 = CSTRING_TSCP( t3934 );
        CONSTANTEXP( ADR( c2769 ) );
        c2745 = CSTRING_TSCP( t3935 );
        CONSTANTEXP( ADR( c2745 ) );
        c2731 = CSTRING_TSCP( t3936 );
        CONSTANTEXP( ADR( c2731 ) );
        c2728 = EMPTYLIST;
        t3937 = CSTRING_TSCP( t3938 );
        c2728 = CONS( t3937, c2728 );
        CONSTANTEXP( ADR( c2728 ) );
        c2717 = CSTRING_TSCP( t3939 );
        CONSTANTEXP( ADR( c2717 ) );
        c2716 = CSTRING_TSCP( t3940 );
        CONSTANTEXP( ADR( c2716 ) );
        c2706 = CSTRING_TSCP( t3941 );
        CONSTANTEXP( ADR( c2706 ) );
        c2692 = CSTRING_TSCP( t3942 );
        CONSTANTEXP( ADR( c2692 ) );
        c2690 = CSTRING_TSCP( t3943 );
        CONSTANTEXP( ADR( c2690 ) );
        c2687 = CSTRING_TSCP( t3944 );
        CONSTANTEXP( ADR( c2687 ) );
        c2664 = CSTRING_TSCP( t3945 );
        CONSTANTEXP( ADR( c2664 ) );
        c2652 = STRINGTOSYMBOL( CSTRING_TSCP( "LOCALS" ) );
        CONSTANTEXP( ADR( c2652 ) );
        c2648 = STRINGTOSYMBOL( CSTRING_TSCP( "PROC" ) );
        CONSTANTEXP( ADR( c2648 ) );
        c2644 = STRINGTOSYMBOL( CSTRING_TSCP( "INDENT" ) );
        CONSTANTEXP( ADR( c2644 ) );
        c2637 = STRINGTOSYMBOL( CSTRING_TSCP( "LIT" ) );
        CONSTANTEXP( ADR( c2637 ) );
        c2607 = CSTRING_TSCP( t3946 );
        CONSTANTEXP( ADR( c2607 ) );
        c2606 = CSTRING_TSCP( t3947 );
        CONSTANTEXP( ADR( c2606 ) );
        c2563 = STRINGTOSYMBOL( CSTRING_TSCP( "LAP" ) );
        CONSTANTEXP( ADR( c2563 ) );
        c2546 = STRINGTOSYMBOL( CSTRING_TSCP( "X299" ) );
        CONSTANTEXP( ADR( c2546 ) );
        c2545 = CSTRING_TSCP( t3948 );
        CONSTANTEXP( ADR( c2545 ) );
        c2518 = EMPTYLIST;
        c2518 = CONS( c2546, c2518 );
        c2518 = CONS( t3608, c2518 );
        c2518 = CONS( t3609, c2518 );
        c2518 = CONS( t3610, c2518 );
        c2518 = CONS( t3611, c2518 );
        c2518 = CONS( t3612, c2518 );
        c2518 = CONS( t3613, c2518 );
        c2518 = CONS( t3614, c2518 );
        c2518 = CONS( t3615, c2518 );
        c2518 = CONS( t3616, c2518 );
        c2518 = CONS( t3617, c2518 );
        c2518 = CONS( t3618, c2518 );
        c2518 = CONS( t3619, c2518 );
        c2518 = CONS( t3620, c2518 );
        c2518 = CONS( t3621, c2518 );
        c2518 = CONS( t3622, c2518 );
        c2518 = CONS( t3623, c2518 );
        c2518 = CONS( t3624, c2518 );
        c2518 = CONS( t3625, c2518 );
        c2518 = CONS( t3626, c2518 );
        c2518 = CONS( t3627, c2518 );
        c2518 = CONS( t3628, c2518 );
        c2518 = CONS( t3629, c2518 );
        c2518 = CONS( t3630, c2518 );
        c2518 = CONS( t3631, c2518 );
        c2518 = CONS( t3632, c2518 );
        c2518 = CONS( t3633, c2518 );
        c2518 = CONS( t3634, c2518 );
        c2518 = CONS( t3635, c2518 );
        c2518 = CONS( t3636, c2518 );
        c2518 = CONS( t3637, c2518 );
        c2518 = CONS( t3638, c2518 );
        c2518 = CONS( t3639, c2518 );
        c2518 = CONS( t3640, c2518 );
        c2518 = CONS( t3641, c2518 );
        c2518 = CONS( t3642, c2518 );
        c2518 = CONS( t3643, c2518 );
        c2518 = CONS( t3644, c2518 );
        c2518 = CONS( t3645, c2518 );
        c2518 = CONS( t3646, c2518 );
        c2518 = CONS( t3647, c2518 );
        c2518 = CONS( t3648, c2518 );
        c2518 = CONS( t3649, c2518 );
        c2518 = CONS( t3650, c2518 );
        c2518 = CONS( t3651, c2518 );
        c2518 = CONS( t3652, c2518 );
        c2518 = CONS( t3653, c2518 );
        c2518 = CONS( t3654, c2518 );
        c2518 = CONS( t3655, c2518 );
        c2518 = CONS( t3656, c2518 );
        c2518 = CONS( t3657, c2518 );
        c2518 = CONS( t3658, c2518 );
        c2518 = CONS( t3659, c2518 );
        c2518 = CONS( t3660, c2518 );
        c2518 = CONS( t3661, c2518 );
        c2518 = CONS( t3662, c2518 );
        c2518 = CONS( t3663, c2518 );
        c2518 = CONS( t3664, c2518 );
        c2518 = CONS( t3665, c2518 );
        c2518 = CONS( t3666, c2518 );
        c2518 = CONS( t3667, c2518 );
        c2518 = CONS( t3668, c2518 );
        c2518 = CONS( t3669, c2518 );
        c2518 = CONS( t3670, c2518 );
        c2518 = CONS( t3671, c2518 );
        c2518 = CONS( t3672, c2518 );
        c2518 = CONS( t3673, c2518 );
        c2518 = CONS( t3674, c2518 );
        c2518 = CONS( t3675, c2518 );
        c2518 = CONS( t3676, c2518 );
        c2518 = CONS( t3677, c2518 );
        c2518 = CONS( t3678, c2518 );
        c2518 = CONS( t3679, c2518 );
        c2518 = CONS( t3680, c2518 );
        c2518 = CONS( t3681, c2518 );
        c2518 = CONS( t3682, c2518 );
        c2518 = CONS( t3683, c2518 );
        c2518 = CONS( t3684, c2518 );
        c2518 = CONS( t3685, c2518 );
        c2518 = CONS( t3686, c2518 );
        c2518 = CONS( t3687, c2518 );
        c2518 = CONS( t3688, c2518 );
        c2518 = CONS( t3689, c2518 );
        c2518 = CONS( t3690, c2518 );
        c2518 = CONS( t3691, c2518 );
        c2518 = CONS( t3692, c2518 );
        c2518 = CONS( t3693, c2518 );
        c2518 = CONS( t3694, c2518 );
        c2518 = CONS( t3695, c2518 );
        c2518 = CONS( t3696, c2518 );
        c2518 = CONS( t3697, c2518 );
        c2518 = CONS( t3698, c2518 );
        c2518 = CONS( t3699, c2518 );
        c2518 = CONS( t3700, c2518 );
        c2518 = CONS( t3701, c2518 );
        c2518 = CONS( t3702, c2518 );
        c2518 = CONS( t3703, c2518 );
        c2518 = CONS( t3704, c2518 );
        c2518 = CONS( t3705, c2518 );
        c2518 = CONS( t3706, c2518 );
        c2518 = CONS( t3707, c2518 );
        c2518 = CONS( t3708, c2518 );
        c2518 = CONS( t3709, c2518 );
        c2518 = CONS( t3710, c2518 );
        c2518 = CONS( t3711, c2518 );
        c2518 = CONS( t3712, c2518 );
        c2518 = CONS( t3713, c2518 );
        c2518 = CONS( t3714, c2518 );
        c2518 = CONS( t3715, c2518 );
        c2518 = CONS( t3716, c2518 );
        c2518 = CONS( t3717, c2518 );
        c2518 = CONS( t3718, c2518 );
        c2518 = CONS( t3719, c2518 );
        c2518 = CONS( t3720, c2518 );
        c2518 = CONS( t3721, c2518 );
        c2518 = CONS( t3722, c2518 );
        c2518 = CONS( t3723, c2518 );
        c2518 = CONS( t3724, c2518 );
        c2518 = CONS( t3725, c2518 );
        c2518 = CONS( t3726, c2518 );
        c2518 = CONS( t3727, c2518 );
        c2518 = CONS( t3728, c2518 );
        c2518 = CONS( t3729, c2518 );
        c2518 = CONS( t3730, c2518 );
        c2518 = CONS( t3731, c2518 );
        c2518 = CONS( t3732, c2518 );
        c2518 = CONS( t3733, c2518 );
        c2518 = CONS( t3734, c2518 );
        c2518 = CONS( t3735, c2518 );
        c2518 = CONS( t3736, c2518 );
        c2518 = CONS( t3737, c2518 );
        c2518 = CONS( t3738, c2518 );
        c2518 = CONS( t3739, c2518 );
        c2518 = CONS( t3740, c2518 );
        c2518 = CONS( t3741, c2518 );
        c2518 = CONS( t3742, c2518 );
        c2518 = CONS( t3743, c2518 );
        c2518 = CONS( t3744, c2518 );
        c2518 = CONS( t3745, c2518 );
        c2518 = CONS( t3746, c2518 );
        c2518 = CONS( t3747, c2518 );
        c2518 = CONS( t3748, c2518 );
        c2518 = CONS( t3749, c2518 );
        c2518 = CONS( t3750, c2518 );
        c2518 = CONS( t3751, c2518 );
        c2518 = CONS( t3752, c2518 );
        c2518 = CONS( t3753, c2518 );
        c2518 = CONS( t3754, c2518 );
        c2518 = CONS( t3755, c2518 );
        c2518 = CONS( t3756, c2518 );
        c2518 = CONS( t3757, c2518 );
        c2518 = CONS( t3758, c2518 );
        c2518 = CONS( t3759, c2518 );
        c2518 = CONS( t3760, c2518 );
        c2518 = CONS( t3761, c2518 );
        c2518 = CONS( t3762, c2518 );
        c2518 = CONS( t3763, c2518 );
        c2518 = CONS( t3764, c2518 );
        c2518 = CONS( t3765, c2518 );
        c2518 = CONS( t3766, c2518 );
        c2518 = CONS( t3767, c2518 );
        c2518 = CONS( t3768, c2518 );
        c2518 = CONS( t3769, c2518 );
        c2518 = CONS( t3770, c2518 );
        c2518 = CONS( t3771, c2518 );
        c2518 = CONS( t3772, c2518 );
        c2518 = CONS( t3773, c2518 );
        c2518 = CONS( t3774, c2518 );
        c2518 = CONS( t3775, c2518 );
        c2518 = CONS( t3776, c2518 );
        c2518 = CONS( t3777, c2518 );
        c2518 = CONS( t3778, c2518 );
        c2518 = CONS( t3779, c2518 );
        c2518 = CONS( t3780, c2518 );
        c2518 = CONS( t3781, c2518 );
        c2518 = CONS( t3782, c2518 );
        c2518 = CONS( t3783, c2518 );
        c2518 = CONS( t3784, c2518 );
        c2518 = CONS( t3785, c2518 );
        c2518 = CONS( t3786, c2518 );
        c2518 = CONS( t3787, c2518 );
        c2518 = CONS( t3788, c2518 );
        c2518 = CONS( t3789, c2518 );
        c2518 = CONS( t3790, c2518 );
        c2518 = CONS( t3791, c2518 );
        c2518 = CONS( t3792, c2518 );
        c2518 = CONS( t3793, c2518 );
        c2518 = CONS( t3794, c2518 );
        c2518 = CONS( t3795, c2518 );
        c2518 = CONS( t3796, c2518 );
        c2518 = CONS( t3797, c2518 );
        c2518 = CONS( t3798, c2518 );
        c2518 = CONS( t3799, c2518 );
        c2518 = CONS( t3800, c2518 );
        c2518 = CONS( t3801, c2518 );
        c2518 = CONS( t3802, c2518 );
        c2518 = CONS( t3803, c2518 );
        c2518 = CONS( t3804, c2518 );
        c2518 = CONS( t3805, c2518 );
        c2518 = CONS( t3806, c2518 );
        c2518 = CONS( t3807, c2518 );
        c2518 = CONS( t3808, c2518 );
        c2518 = CONS( t3809, c2518 );
        c2518 = CONS( t3810, c2518 );
        c2518 = CONS( t3811, c2518 );
        c2518 = CONS( t3812, c2518 );
        c2518 = CONS( t3813, c2518 );
        c2518 = CONS( t3814, c2518 );
        c2518 = CONS( t3815, c2518 );
        c2518 = CONS( t3816, c2518 );
        c2518 = CONS( t3817, c2518 );
        c2518 = CONS( t3818, c2518 );
        c2518 = CONS( t3819, c2518 );
        c2518 = CONS( t3820, c2518 );
        c2518 = CONS( t3821, c2518 );
        c2518 = CONS( t3822, c2518 );
        c2518 = CONS( t3823, c2518 );
        c2518 = CONS( t3824, c2518 );
        c2518 = CONS( t3825, c2518 );
        c2518 = CONS( t3826, c2518 );
        c2518 = CONS( t3827, c2518 );
        c2518 = CONS( t3828, c2518 );
        c2518 = CONS( t3829, c2518 );
        c2518 = CONS( t3830, c2518 );
        c2518 = CONS( t3831, c2518 );
        c2518 = CONS( t3832, c2518 );
        c2518 = CONS( t3833, c2518 );
        c2518 = CONS( t3834, c2518 );
        c2518 = CONS( t3835, c2518 );
        c2518 = CONS( t3836, c2518 );
        c2518 = CONS( t3837, c2518 );
        c2518 = CONS( t3838, c2518 );
        c2518 = CONS( t3839, c2518 );
        c2518 = CONS( t3840, c2518 );
        c2518 = CONS( t3841, c2518 );
        c2518 = CONS( t3842, c2518 );
        c2518 = CONS( t3843, c2518 );
        c2518 = CONS( t3844, c2518 );
        c2518 = CONS( t3845, c2518 );
        c2518 = CONS( t3846, c2518 );
        c2518 = CONS( t3847, c2518 );
        c2518 = CONS( t3848, c2518 );
        c2518 = CONS( t3849, c2518 );
        c2518 = CONS( t3850, c2518 );
        c2518 = CONS( t3851, c2518 );
        c2518 = CONS( t3852, c2518 );
        c2518 = CONS( t3853, c2518 );
        c2518 = CONS( t3854, c2518 );
        c2518 = CONS( t3855, c2518 );
        c2518 = CONS( t3856, c2518 );
        c2518 = CONS( t3857, c2518 );
        c2518 = CONS( t3858, c2518 );
        c2518 = CONS( t3859, c2518 );
        c2518 = CONS( t3860, c2518 );
        c2518 = CONS( t3861, c2518 );
        c2518 = CONS( t3862, c2518 );
        c2518 = CONS( t3863, c2518 );
        c2518 = CONS( t3864, c2518 );
        c2518 = CONS( t3865, c2518 );
        c2518 = CONS( t3866, c2518 );
        c2518 = CONS( t3867, c2518 );
        c2518 = CONS( t3868, c2518 );
        c2518 = CONS( t3869, c2518 );
        c2518 = CONS( t3870, c2518 );
        c2518 = CONS( t3871, c2518 );
        c2518 = CONS( t3872, c2518 );
        c2518 = CONS( t3873, c2518 );
        c2518 = CONS( t3874, c2518 );
        c2518 = CONS( t3875, c2518 );
        c2518 = CONS( t3876, c2518 );
        c2518 = CONS( t3877, c2518 );
        c2518 = CONS( t3878, c2518 );
        c2518 = CONS( t3879, c2518 );
        c2518 = CONS( t3880, c2518 );
        c2518 = CONS( t3881, c2518 );
        c2518 = CONS( t3882, c2518 );
        c2518 = CONS( t3883, c2518 );
        c2518 = CONS( t3884, c2518 );
        c2518 = CONS( t3885, c2518 );
        c2518 = CONS( t3886, c2518 );
        c2518 = CONS( t3887, c2518 );
        c2518 = CONS( t3888, c2518 );
        c2518 = CONS( t3889, c2518 );
        c2518 = CONS( t3890, c2518 );
        c2518 = CONS( t3891, c2518 );
        c2518 = CONS( t3892, c2518 );
        c2518 = CONS( t3893, c2518 );
        c2518 = CONS( t3894, c2518 );
        c2518 = CONS( t3895, c2518 );
        c2518 = CONS( t3896, c2518 );
        c2518 = CONS( t3897, c2518 );
        c2518 = CONS( t3898, c2518 );
        c2518 = CONS( t3899, c2518 );
        c2518 = CONS( t3900, c2518 );
        c2518 = CONS( t3901, c2518 );
        c2518 = CONS( t3902, c2518 );
        c2518 = CONS( t3903, c2518 );
        c2518 = CONS( t3904, c2518 );
        c2518 = CONS( t3905, c2518 );
        CONSTANTEXP( ADR( c2518 ) );
        c2407 = STRINGTOSYMBOL( CSTRING_TSCP( "NOT" ) );
        CONSTANTEXP( ADR( c2407 ) );
        c2354 = STRINGTOSYMBOL( CSTRING_TSCP( "IF" ) );
        CONSTANTEXP( ADR( c2354 ) );
        c2213 = EMPTYLIST;
        t3949 = STRINGTOSYMBOL( CSTRING_TSCP( "LABEL" ) );
        c2213 = CONS( t3949, c2213 );
        c2213 = CONS( c2644, c2213 );
        c2213 = CONS( c2637, c2213 );
        CONSTANTEXP( ADR( c2213 ) );
        c2207 = STRINGTOSYMBOL( CSTRING_TSCP( "RETURN" ) );
        CONSTANTEXP( ADR( c2207 ) );
        c2185 = STRINGTOSYMBOL( CSTRING_TSCP( "GOTO" ) );
        CONSTANTEXP( ADR( c2185 ) );
        c2143 = STRINGTOSYMBOL( CSTRING_TSCP( "TOS" ) );
        CONSTANTEXP( ADR( c2143 ) );
        c2132 = STRINGTOSYMBOL( CSTRING_TSCP( "NO-VALUE" ) );
        CONSTANTEXP( ADR( c2132 ) );
        c2111 = STRINGTOSYMBOL( CSTRING_TSCP( "SET" ) );
        CONSTANTEXP( ADR( c2111 ) );
        c2100 = STRINGTOSYMBOL( CSTRING_TSCP( "LABEL" ) );
        CONSTANTEXP( ADR( c2100 ) );
        c2084 = CSTRING_TSCP( t3950 );
        CONSTANTEXP( ADR( c2084 ) );
        c2053 = CSTRING_TSCP( t3951 );
        CONSTANTEXP( ADR( c2053 ) );
        c2032 = CSTRING_TSCP( t3952 );
        CONSTANTEXP( ADR( c2032 ) );
        c2020 = CSTRING_TSCP( t3953 );
        CONSTANTEXP( ADR( c2020 ) );
        c2016 = STRINGTOSYMBOL( CSTRING_TSCP( "PEEP" ) );
        CONSTANTEXP( ADR( c2016 ) );
}

DEFTSCP( lap_global_2dlap_2dcode_v );
DEFCSTRING( t3954, "GLOBAL-LAP-CODE" );
DEFTSCP( lap_emit_2dglobal_2dlap_v );
DEFCSTRING( t3955, "EMIT-GLOBAL-LAP" );
EXTERNTSCPP( sc_cons, XAL2( TSCP, TSCP ) );
EXTERNTSCP( sc_cons_v );

TSCP  lap_emit_2dglobal_2dlap( c2003 )
        TSCP  c2003;
{
        PUSHSTACKTRACE( t3955 );
        POPSTACKTRACE( SET( lap_global_2dlap_2dcode_v, 
                            sc_cons( c2003, lap_global_2dlap_2dcode_v ) ) );
}

DEFTSCP( lap_lap_2dcode_v );
DEFCSTRING( t3957, "LAP-CODE" );
DEFTSCP( lap_emit_2dlap_v );
DEFCSTRING( t3958, "EMIT-LAP" );
EXTERNTSCPP( lap_peep_2dlap, XAL1( TSCP ) );
EXTERNTSCP( lap_peep_2dlap_v );
EXTERNTSCPP( scrt1_equal_3f, XAL2( TSCP, TSCP ) );
EXTERNTSCP( scrt1_equal_3f_v );
EXTERNTSCPP( scrt6_format, XAL2( TSCP, TSCP ) );
EXTERNTSCP( scrt6_format_v );
EXTERNTSCPP( scrt1_length, XAL1( TSCP ) );
EXTERNTSCP( scrt1_length_v );
EXTERNTSCPP( scrt2__2d_2dtwo, XAL2( TSCP, TSCP ) );
EXTERNTSCP( scrt2__2d_2dtwo_v );
EXTERNTSCPP( scrt2_min_2dtwo, XAL2( TSCP, TSCP ) );
EXTERNTSCP( scrt2_min_2dtwo_v );
EXTERNTSCPP( scrt2_negative_3f, XAL1( TSCP ) );
EXTERNTSCP( scrt2_negative_3f_v );
EXTERNTSCPP( scrt1_list_2dref, XAL2( TSCP, TSCP ) );
EXTERNTSCP( scrt1_list_2dref_v );

TSCP  lap_emit_2dlap( c2007 )
        TSCP  c2007;
{
        TSCP  X5, X4, X3, X2, X1;

        PUSHSTACKTRACE( t3958 );
        X1 = lap_lap_2dcode_v;
        X2 = lap_peep_2dlap( c2007 );
        X3 = SYMBOL_VALUE( log_3f_v );
        X3 = UNKNOWNCALL( X3, 1 );
        if  ( FALSE( VIA( PROCEDURE_CODE( X3 ) )( c2016, 
                                                  PROCEDURE_CLOSURE( X3 ) ) )
            )  goto L3962;
        X3 = sc_cons( c2007, X1 );
        if  ( TRUE( scrt1_equal_3f( X2, X3 ) ) )  goto L3964;
        X3 = SYMBOL_VALUE( sc_2dicode_v );
        scrt6_format( X3, CONS( c2020, EMPTYLIST ) );
        X5 = scrt1_length( X1 );
        if  ( BITAND( BITOR( _S2CINT( X5 ), 
                             _S2CINT( _TSCP( 4 ) ) ), 
                      3 ) )  goto L3969;
        X4 = _TSCP( IDIFFERENCE( _S2CINT( X5 ), 
                                 _S2CINT( _TSCP( 4 ) ) ) );
        goto L3970;
L3969:
        X4 = scrt2__2d_2dtwo( X5, _TSCP( 4 ) );
L3970:
        if  ( BITAND( BITOR( _S2CINT( _TSCP( 4 ) ), 
                             _S2CINT( X4 ) ), 
                      3 ) )  goto L3972;
        if  ( GTE( _S2CINT( _TSCP( 4 ) ), _S2CINT( X4 ) ) )  goto L3974;
        X3 = _TSCP( 4 );
        goto L3973;
L3974:
        X3 = X4;
        goto L3973;
L3972:
        X3 = scrt2_min_2dtwo( _TSCP( 4 ), X4 );
L3973:
        if  ( NEQ( TSCPTAG( X3 ), FIXNUMTAG ) )  goto L3978;
        if  ( GTE( _S2CINT( X3 ), 0 ) )  goto L3982;
        goto L3985;
L3978:
        if  ( TRUE( scrt2_negative_3f( X3 ) ) )  goto L3985;
L3982:
        X4 = SYMBOL_VALUE( sc_2dicode_v );
        X5 = CONS( scrt1_list_2dref( X1, X3 ), EMPTYLIST );
        scrt6_format( X4, CONS( c2032, X5 ) );
        if  ( BITAND( BITOR( _S2CINT( X3 ), 
                             _S2CINT( _TSCP( 4 ) ) ), 
                      3 ) )  goto L3987;
        X3 = _TSCP( IDIFFERENCE( _S2CINT( X3 ), 
                                 _S2CINT( _TSCP( 4 ) ) ) );
        GOBACK( L3973 );
L3987:
        X3 = scrt2__2d_2dtwo( X3, _TSCP( 4 ) );
        GOBACK( L3973 );
L3985:
        X3 = SYMBOL_VALUE( sc_2dicode_v );
        X4 = CONS( c2007, EMPTYLIST );
        scrt6_format( X3, CONS( c2053, X4 ) );
        X5 = scrt1_length( X2 );
        if  ( BITAND( BITOR( _S2CINT( X5 ), 
                             _S2CINT( _TSCP( 4 ) ) ), 
                      3 ) )  goto L3991;
        X4 = _TSCP( IDIFFERENCE( _S2CINT( X5 ), 
                                 _S2CINT( _TSCP( 4 ) ) ) );
        goto L3992;
L3991:
        X4 = scrt2__2d_2dtwo( X5, _TSCP( 4 ) );
L3992:
        if  ( BITAND( BITOR( _S2CINT( _TSCP( 8 ) ), 
                             _S2CINT( X4 ) ), 
                      3 ) )  goto L3994;
        if  ( GTE( _S2CINT( _TSCP( 8 ) ), _S2CINT( X4 ) ) )  goto L3996;
        X3 = _TSCP( 8 );
        goto L3995;
L3996:
        X3 = X4;
        goto L3995;
L3994:
        X3 = scrt2_min_2dtwo( _TSCP( 8 ), X4 );
L3995:
        if  ( NEQ( TSCPTAG( X3 ), FIXNUMTAG ) )  goto L4000;
        if  ( GTE( _S2CINT( X3 ), 0 ) )  goto L4004;
        goto L4007;
L4000:
        if  ( TRUE( scrt2_negative_3f( X3 ) ) )  goto L4007;
L4004:
        X4 = SYMBOL_VALUE( sc_2dicode_v );
        X5 = CONS( scrt1_list_2dref( X2, X3 ), EMPTYLIST );
        scrt6_format( X4, CONS( c2032, X5 ) );
        if  ( BITAND( BITOR( _S2CINT( X3 ), 
                             _S2CINT( _TSCP( 4 ) ) ), 
                      3 ) )  goto L4009;
        X3 = _TSCP( IDIFFERENCE( _S2CINT( X3 ), 
                                 _S2CINT( _TSCP( 4 ) ) ) );
        GOBACK( L3995 );
L4009:
        X3 = scrt2__2d_2dtwo( X3, _TSCP( 4 ) );
        GOBACK( L3995 );
L4007:
        X3 = SYMBOL_VALUE( sc_2dicode_v );
        POPSTACKTRACE( scrt6_format( X3, 
                                     CONS( c2084, EMPTYLIST ) ) );
L3964:
        POPSTACKTRACE( FALSEVALUE );
L3962:
        POPSTACKTRACE( FALSEVALUE );
}

DEFTSCP( lap_peep_2dlap_v );
DEFCSTRING( t4011, "PEEP-LAP" );
EXTERNTSCPP( scrt1__24__car_2derror, XAL1( TSCP ) );
EXTERNTSCP( scrt1__24__car_2derror_v );
EXTERNTSCPP( scrt1__24__cdr_2derror, XAL1( TSCP ) );
EXTERNTSCP( scrt1__24__cdr_2derror_v );
EXTERNTSCPP( scrt1_cadar, XAL1( TSCP ) );
EXTERNTSCP( scrt1_cadar_v );
EXTERNTSCPP( lap_resolve_2dlabel, XAL1( TSCP ) );
EXTERNTSCP( lap_resolve_2dlabel_v );
EXTERNTSCPP( scrt2__2b_2dtwo, XAL2( TSCP, TSCP ) );
EXTERNTSCP( scrt2__2b_2dtwo_v );
EXTERNTSCPP( lap_bump_2dlabel_2dgotos, XAL2( TSCP, TSCP ) );
EXTERNTSCP( lap_bump_2dlabel_2dgotos_v );
EXTERNTSCPP( scrt1_caadr, XAL1( TSCP ) );
EXTERNTSCP( scrt1_caadr_v );
EXTERNTSCPP( scrt1_caddr, XAL1( TSCP ) );
EXTERNTSCP( scrt1_caddr_v );
EXTERNTSCPP( scrt1_cadadr, XAL1( TSCP ) );
EXTERNTSCP( scrt1_cadadr_v );
EXTERNTSCPP( scrt1_cons_2a, XAL2( TSCP, TSCP ) );
EXTERNTSCP( scrt1_cons_2a_v );
EXTERNTSCPP( scrt1_memq, XAL2( TSCP, TSCP ) );
EXTERNTSCP( scrt1_memq_v );

TSCP  lap_peep_2dlap( c2087 )
        TSCP  c2087;
{
        TSCP  X12, 
              X11, 
              X10, 
              X9, 
              X8, X7, X6, X5, X4, X3, X2, X1;

        PUSHSTACKTRACE( t4011 );
        c2087 = CONS( c2087, EMPTYLIST );
        if  ( NEQ( _S2CUINT( lap_lap_2dcode_v ), 
                   _S2CUINT( EMPTYLIST ) ) )  goto L4013;
        lap_lap_2dcode_v = sc_cons( PAIR_CAR( c2087 ), 
                                    lap_lap_2dcode_v );
        goto L4164;
L4013:
        X2 = PAIR_CAR( c2087 );
        if  ( EQ( TSCPTAG( X2 ), PAIRTAG ) )  goto L4018;
        scrt1__24__car_2derror( X2 );
L4018:
        X1 = PAIR_CAR( X2 );
        if  ( NEQ( _S2CUINT( X1 ), _S2CUINT( c2100 ) ) )  goto L4015;
        X2 = lap_lap_2dcode_v;
        if  ( EQ( TSCPTAG( X2 ), PAIRTAG ) )  goto L4024;
        scrt1__24__car_2derror( X2 );
L4024:
        X3 = PAIR_CAR( X2 );
        if  ( EQ( TSCPTAG( X3 ), PAIRTAG ) )  goto L4027;
        scrt1__24__car_2derror( X3 );
L4027:
        X1 = PAIR_CAR( X3 );
        if  ( NEQ( _S2CUINT( X1 ), _S2CUINT( c2100 ) ) )  goto L4020;
        X2 = PAIR_CAR( c2087 );
        if  ( EQ( TSCPTAG( X2 ), PAIRTAG ) )  goto L4031;
        scrt1__24__cdr_2derror( X2 );
L4031:
        X3 = PAIR_CDR( X2 );
        if  ( EQ( TSCPTAG( X3 ), PAIRTAG ) )  goto L4034;
        scrt1__24__car_2derror( X3 );
L4034:
        X1 = PAIR_CAR( X3 );
        X3 = scrt1_cadar( lap_lap_2dcode_v );
        X2 = SYMBOL_VALUE( set_2did_2dalias_21_v );
        X2 = UNKNOWNCALL( X2, 2 );
        VIA( PROCEDURE_CODE( X2 ) )( X1, 
                                     X3, PROCEDURE_CLOSURE( X2 ) );
        X3 = lap_resolve_2dlabel( X1 );
        X7 = lap_resolve_2dlabel( X1 );
        X6 = SYMBOL_VALUE( id_2dgotos_v );
        X6 = UNKNOWNCALL( X6, 1 );
        X5 = VIA( PROCEDURE_CODE( X6 ) )( X7, 
                                          PROCEDURE_CLOSURE( X6 ) );
        X7 = SYMBOL_VALUE( id_2dgotos_v );
        X7 = UNKNOWNCALL( X7, 1 );
        X6 = VIA( PROCEDURE_CODE( X7 ) )( X1, 
                                          PROCEDURE_CLOSURE( X7 ) );
        if  ( BITAND( BITOR( _S2CINT( X5 ), _S2CINT( X6 ) ), 
                      3 ) )  goto L4038;
        X4 = _TSCP( IPLUS( _S2CINT( X5 ), _S2CINT( X6 ) ) );
        goto L4039;
L4038:
        X4 = scrt2__2b_2dtwo( X5, X6 );
L4039:
        X2 = SYMBOL_VALUE( set_2did_2dgotos_21_v );
        X2 = UNKNOWNCALL( X2, 2 );
        VIA( PROCEDURE_CODE( X2 ) )( X3, 
                                     X4, PROCEDURE_CLOSURE( X2 ) );
        X3 = lap_lap_2dcode_v;
        if  ( EQ( TSCPTAG( X3 ), PAIRTAG ) )  goto L4041;
        scrt1__24__car_2derror( X3 );
L4041:
        X2 = PAIR_CAR( X3 );
        SETGEN( PAIR_CAR( c2087 ), X2 );
        X2 = lap_lap_2dcode_v;
        if  ( EQ( TSCPTAG( X2 ), PAIRTAG ) )  goto L4044;
        scrt1__24__cdr_2derror( X2 );
L4044:
        lap_lap_2dcode_v = PAIR_CDR( X2 );
        lap_emit_2dlap( PAIR_CAR( c2087 ) );
        goto L4164;
L4020:
        X2 = lap_lap_2dcode_v;
        if  ( EQ( TSCPTAG( X2 ), PAIRTAG ) )  goto L4049;
        scrt1__24__car_2derror( X2 );
L4049:
        X1 = PAIR_CAR( X2 );
        X6 = PAIR_CAR( c2087 );
        if  ( EQ( TSCPTAG( X6 ), PAIRTAG ) )  goto L4053;
        scrt1__24__cdr_2derror( X6 );
L4053:
        X7 = PAIR_CDR( X6 );
        if  ( EQ( TSCPTAG( X7 ), PAIRTAG ) )  goto L4056;
        scrt1__24__car_2derror( X7 );
L4056:
        X5 = PAIR_CAR( X7 );
        X4 = sc_cons( X5, EMPTYLIST );
        X3 = sc_cons( c2185, X4 );
        X2 = X3;
        if  ( FALSE( scrt1_equal_3f( X1, X2 ) ) )  goto L4046;
        X2 = lap_lap_2dcode_v;
        if  ( EQ( TSCPTAG( X2 ), PAIRTAG ) )  goto L4061;
        scrt1__24__car_2derror( X2 );
L4061:
        X1 = PAIR_CAR( X2 );
        lap_bump_2dlabel_2dgotos( X1, _TSCP( -4 ) );
        X1 = lap_lap_2dcode_v;
        if  ( EQ( TSCPTAG( X1 ), PAIRTAG ) )  goto L4064;
        scrt1__24__cdr_2derror( X1 );
L4064:
        lap_lap_2dcode_v = PAIR_CDR( X1 );
        lap_emit_2dlap( PAIR_CAR( c2087 ) );
        goto L4164;
L4046:
        X3 = lap_lap_2dcode_v;
        if  ( EQ( TSCPTAG( X3 ), PAIRTAG ) )  goto L4068;
        scrt1__24__car_2derror( X3 );
L4068:
        X4 = PAIR_CAR( X3 );
        if  ( EQ( TSCPTAG( X4 ), PAIRTAG ) )  goto L4071;
        scrt1__24__car_2derror( X4 );
L4071:
        X2 = PAIR_CAR( X4 );
        X1 = BOOLEAN( EQ( _S2CUINT( X2 ), 
                          _S2CUINT( c2185 ) ) );
        if  ( FALSE( X1 ) )  goto L4137;
        X2 = scrt1_caadr( lap_lap_2dcode_v );
        if  ( NEQ( _S2CUINT( X2 ), _S2CUINT( c2354 ) ) )  goto L4137;
        X5 = lap_lap_2dcode_v;
        if  ( EQ( TSCPTAG( X5 ), PAIRTAG ) )  goto L4084;
        scrt1__24__cdr_2derror( X5 );
L4084:
        X6 = PAIR_CDR( X5 );
        if  ( EQ( TSCPTAG( X6 ), PAIRTAG ) )  goto L4087;
        scrt1__24__car_2derror( X6 );
L4087:
        X4 = PAIR_CAR( X6 );
        X3 = scrt1_caddr( X4 );
        X2 = lap_resolve_2dlabel( X3 );
        X5 = PAIR_CAR( c2087 );
        if  ( EQ( TSCPTAG( X5 ), PAIRTAG ) )  goto L4091;
        scrt1__24__cdr_2derror( X5 );
L4091:
        X6 = PAIR_CDR( X5 );
        if  ( EQ( TSCPTAG( X6 ), PAIRTAG ) )  goto L4094;
        scrt1__24__car_2derror( X6 );
L4094:
        X4 = PAIR_CAR( X6 );
        X3 = lap_resolve_2dlabel( X4 );
        if  ( NEQ( _S2CUINT( X2 ), _S2CUINT( X3 ) ) )  goto L4137;
        X2 = scrt1_cadadr( lap_lap_2dcode_v );
        X2 = CONS( X2, EMPTYLIST );
        if  ( NEQ( TSCPTAG( PAIR_CAR( X2 ) ), PAIRTAG ) )  goto L4097;
        X4 = PAIR_CAR( X2 );
        if  ( EQ( TSCPTAG( X4 ), PAIRTAG ) )  goto L4100;
        scrt1__24__car_2derror( X4 );
L4100:
        X3 = PAIR_CAR( X4 );
        goto L4098;
L4097:
        X3 = FALSEVALUE;
L4098:
        X5 = lap_lap_2dcode_v;
        if  ( EQ( TSCPTAG( X5 ), PAIRTAG ) )  goto L4105;
        scrt1__24__cdr_2derror( X5 );
L4105:
        X6 = PAIR_CDR( X5 );
        if  ( EQ( TSCPTAG( X6 ), PAIRTAG ) )  goto L4108;
        scrt1__24__car_2derror( X6 );
L4108:
        X4 = PAIR_CAR( X6 );
        lap_bump_2dlabel_2dgotos( X4, _TSCP( -4 ) );
        X5 = BOOLEAN( EQ( TSCPTAG( PAIR_CAR( X2 ) ), 
                          PAIRTAG ) );
        if  ( FALSE( X5 ) )  goto L4126;
        X7 = PAIR_CAR( X2 );
        if  ( EQ( TSCPTAG( X7 ), PAIRTAG ) )  goto L4117;
        scrt1__24__car_2derror( X7 );
L4117:
        X6 = PAIR_CAR( X7 );
        if  ( NEQ( _S2CUINT( X6 ), _S2CUINT( c2407 ) ) )  goto L4126;
        X6 = PAIR_CAR( X2 );
        if  ( EQ( TSCPTAG( X6 ), PAIRTAG ) )  goto L4121;
        scrt1__24__cdr_2derror( X6 );
L4121:
        X7 = PAIR_CDR( X6 );
        if  ( EQ( TSCPTAG( X7 ), PAIRTAG ) )  goto L4124;
        scrt1__24__car_2derror( X7 );
L4124:
        X4 = PAIR_CAR( X7 );
        goto L4127;
L4126:
        X6 = CONS( EMPTYLIST, EMPTYLIST );
        X4 = scrt1_cons_2a( c2407, 
                            CONS( PAIR_CAR( X2 ), X6 ) );
L4127:
        SETGEN( PAIR_CAR( X2 ), X4 );
        X9 = scrt1_cadar( lap_lap_2dcode_v );
        X8 = sc_cons( X9, EMPTYLIST );
        X7 = sc_cons( PAIR_CAR( X2 ), X8 );
        X6 = sc_cons( c2354, X7 );
        X5 = X6;
        X7 = lap_lap_2dcode_v;
        if  ( EQ( TSCPTAG( X7 ), PAIRTAG ) )  goto L4131;
        scrt1__24__cdr_2derror( X7 );
L4131:
        X8 = PAIR_CDR( X7 );
        if  ( EQ( TSCPTAG( X8 ), PAIRTAG ) )  goto L4134;
        scrt1__24__cdr_2derror( X8 );
L4134:
        X6 = PAIR_CDR( X8 );
        X4 = sc_cons( X5, X6 );
        lap_lap_2dcode_v = sc_cons( PAIR_CAR( c2087 ), X4 );
        goto L4164;
L4137:
        lap_lap_2dcode_v = sc_cons( PAIR_CAR( c2087 ), 
                                    lap_lap_2dcode_v );
        goto L4164;
L4015:
        X3 = PAIR_CAR( c2087 );
        if  ( EQ( TSCPTAG( X3 ), PAIRTAG ) )  goto L4140;
        scrt1__24__car_2derror( X3 );
L4140:
        X2 = PAIR_CAR( X3 );
        X1 = BOOLEAN( EQ( _S2CUINT( X2 ), 
                          _S2CUINT( c2111 ) ) );
        if  ( FALSE( X1 ) )  goto L4163;
        X3 = PAIR_CAR( c2087 );
        if  ( EQ( TSCPTAG( X3 ), PAIRTAG ) )  goto L4151;
        scrt1__24__cdr_2derror( X3 );
L4151:
        X4 = PAIR_CDR( X3 );
        if  ( EQ( TSCPTAG( X4 ), PAIRTAG ) )  goto L4154;
        scrt1__24__car_2derror( X4 );
L4154:
        X2 = PAIR_CAR( X4 );
        if  ( NEQ( _S2CUINT( X2 ), _S2CUINT( c2132 ) ) )  goto L4162;
        X2 = scrt1_caddr( PAIR_CAR( c2087 ) );
        if  ( EQ( TSCPTAG( X2 ), PAIRTAG ) )  goto L4162;
        X2 = scrt1_caddr( PAIR_CAR( c2087 ) );
        if  ( NEQ( _S2CUINT( X2 ), _S2CUINT( c2143 ) ) )  goto L4164;
L4162:
        X2 = scrt1_caddr( PAIR_CAR( c2087 ) );
        if  ( EQ( _S2CUINT( X2 ), _S2CUINT( c2132 ) ) )  goto L4164;
        X3 = PAIR_CAR( c2087 );
        if  ( EQ( TSCPTAG( X3 ), PAIRTAG ) )  goto L4171;
        scrt1__24__cdr_2derror( X3 );
L4171:
        X4 = PAIR_CDR( X3 );
        if  ( EQ( TSCPTAG( X4 ), PAIRTAG ) )  goto L4174;
        scrt1__24__car_2derror( X4 );
L4174:
        X2 = PAIR_CAR( X4 );
        X3 = scrt1_caddr( PAIR_CAR( c2087 ) );
        if  ( TRUE( scrt1_equal_3f( X2, X3 ) ) )  goto L4164;
L4163:
        X2 = lap_lap_2dcode_v;
        if  ( FALSE( X2 ) )  goto L4208;
        X5 = lap_lap_2dcode_v;
        if  ( EQ( TSCPTAG( X5 ), PAIRTAG ) )  goto L4184;
        scrt1__24__car_2derror( X5 );
L4184:
        X6 = PAIR_CAR( X5 );
        if  ( EQ( TSCPTAG( X6 ), PAIRTAG ) )  goto L4187;
        scrt1__24__car_2derror( X6 );
L4187:
        X4 = PAIR_CAR( X6 );
        if  ( NEQ( _S2CUINT( X4 ), _S2CUINT( c2185 ) ) )  goto L4180;
        X3 = TRUEVALUE;
        goto L4190;
L4180:
        X5 = lap_lap_2dcode_v;
        if  ( EQ( TSCPTAG( X5 ), PAIRTAG ) )  goto L4193;
        scrt1__24__car_2derror( X5 );
L4193:
        X6 = PAIR_CAR( X5 );
        if  ( EQ( TSCPTAG( X6 ), PAIRTAG ) )  goto L4196;
        scrt1__24__car_2derror( X6 );
L4196:
        X4 = PAIR_CAR( X6 );
        if  ( NEQ( _S2CUINT( X4 ), _S2CUINT( c2111 ) ) )  goto L4189;
        X4 = scrt1_cadar( lap_lap_2dcode_v );
        X3 = BOOLEAN( EQ( _S2CUINT( X4 ), 
                          _S2CUINT( c2207 ) ) );
        goto L4190;
L4189:
        X3 = FALSEVALUE;
L4190:
        if  ( FALSE( X3 ) )  goto L4208;
        X5 = PAIR_CAR( c2087 );
        if  ( EQ( TSCPTAG( X5 ), PAIRTAG ) )  goto L4205;
        scrt1__24__car_2derror( X5 );
L4205:
        X4 = PAIR_CAR( X5 );
        if  ( FALSE( scrt1_memq( X4, c2213 ) ) )  goto L4164;
L4208:
        X4 = PAIR_CAR( c2087 );
        if  ( EQ( TSCPTAG( X4 ), PAIRTAG ) )  goto L4210;
        scrt1__24__car_2derror( X4 );
L4210:
        X3 = PAIR_CAR( X4 );
        X2 = BOOLEAN( EQ( _S2CUINT( X3 ), 
                          _S2CUINT( c2185 ) ) );
        if  ( FALSE( X2 ) )  goto L4264;
        X4 = lap_lap_2dcode_v;
        if  ( EQ( TSCPTAG( X4 ), PAIRTAG ) )  goto L4221;
        scrt1__24__car_2derror( X4 );
L4221:
        X5 = PAIR_CAR( X4 );
        if  ( EQ( TSCPTAG( X5 ), PAIRTAG ) )  goto L4224;
        scrt1__24__car_2derror( X5 );
L4224:
        X3 = PAIR_CAR( X5 );
        if  ( NEQ( _S2CUINT( X3 ), _S2CUINT( c2100 ) ) )  goto L4264;
        X5 = PAIR_CAR( c2087 );
        if  ( EQ( TSCPTAG( X5 ), PAIRTAG ) )  goto L4230;
        scrt1__24__cdr_2derror( X5 );
L4230:
        X6 = PAIR_CDR( X5 );
        if  ( EQ( TSCPTAG( X6 ), PAIRTAG ) )  goto L4233;
        scrt1__24__car_2derror( X6 );
L4233:
        X4 = PAIR_CAR( X6 );
        X3 = lap_resolve_2dlabel( X4 );
        X4 = scrt1_cadar( lap_lap_2dcode_v );
        if  ( EQ( _S2CUINT( X3 ), _S2CUINT( X4 ) ) )  goto L4264;
        X4 = scrt1_cadar( lap_lap_2dcode_v );
        X7 = PAIR_CAR( c2087 );
        if  ( EQ( TSCPTAG( X7 ), PAIRTAG ) )  goto L4238;
        scrt1__24__cdr_2derror( X7 );
L4238:
        X8 = PAIR_CDR( X7 );
        if  ( EQ( TSCPTAG( X8 ), PAIRTAG ) )  goto L4241;
        scrt1__24__car_2derror( X8 );
L4241:
        X6 = PAIR_CAR( X8 );
        X5 = lap_resolve_2dlabel( X6 );
        X3 = SYMBOL_VALUE( set_2did_2dalias_21_v );
        X3 = UNKNOWNCALL( X3, 2 );
        VIA( PROCEDURE_CODE( X3 ) )( X4, 
                                     X5, PROCEDURE_CLOSURE( X3 ) );
        X6 = PAIR_CAR( c2087 );
        if  ( EQ( TSCPTAG( X6 ), PAIRTAG ) )  goto L4245;
        scrt1__24__cdr_2derror( X6 );
L4245:
        X7 = PAIR_CDR( X6 );
        if  ( EQ( TSCPTAG( X7 ), PAIRTAG ) )  goto L4248;
        scrt1__24__car_2derror( X7 );
L4248:
        X5 = PAIR_CAR( X7 );
        X4 = lap_resolve_2dlabel( X5 );
        X8 = scrt1_cadar( lap_lap_2dcode_v );
        X7 = SYMBOL_VALUE( id_2dgotos_v );
        X7 = UNKNOWNCALL( X7, 1 );
        X6 = VIA( PROCEDURE_CODE( X7 ) )( X8, 
                                          PROCEDURE_CLOSURE( X7 ) );
        X11 = PAIR_CAR( c2087 );
        if  ( EQ( TSCPTAG( X11 ), PAIRTAG ) )  goto L4252;
        scrt1__24__cdr_2derror( X11 );
L4252:
        X12 = PAIR_CDR( X11 );
        if  ( EQ( TSCPTAG( X12 ), PAIRTAG ) )  goto L4255;
        scrt1__24__car_2derror( X12 );
L4255:
        X10 = PAIR_CAR( X12 );
        X9 = lap_resolve_2dlabel( X10 );
        X8 = SYMBOL_VALUE( id_2dgotos_v );
        X8 = UNKNOWNCALL( X8, 1 );
        X7 = VIA( PROCEDURE_CODE( X8 ) )( X9, 
                                          PROCEDURE_CLOSURE( X8 ) );
        if  ( BITAND( BITOR( _S2CINT( X7 ), _S2CINT( X6 ) ), 
                      3 ) )  goto L4258;
        X5 = _TSCP( IPLUS( _S2CINT( X7 ), _S2CINT( X6 ) ) );
        goto L4259;
L4258:
        X5 = scrt2__2b_2dtwo( X7, X6 );
L4259:
        X3 = SYMBOL_VALUE( set_2did_2dgotos_21_v );
        X3 = UNKNOWNCALL( X3, 2 );
        VIA( PROCEDURE_CODE( X3 ) )( X4, 
                                     X5, PROCEDURE_CLOSURE( X3 ) );
        X3 = lap_lap_2dcode_v;
        if  ( EQ( TSCPTAG( X3 ), PAIRTAG ) )  goto L4261;
        scrt1__24__cdr_2derror( X3 );
L4261:
        lap_lap_2dcode_v = PAIR_CDR( X3 );
        lap_emit_2dlap( PAIR_CAR( c2087 ) );
        goto L4164;
L4264:
        lap_bump_2dlabel_2dgotos( PAIR_CAR( c2087 ), _TSCP( 4 ) );
        lap_lap_2dcode_v = sc_cons( PAIR_CAR( c2087 ), 
                                    lap_lap_2dcode_v );
L4164:
        POPSTACKTRACE( lap_lap_2dcode_v );
}

DEFTSCP( lap_bump_2dlabel_2dgotos_v );
DEFCSTRING( t4266, "BUMP-LABEL-GOTOS" );

TSCP  lap_bump_2dlabel_2dgotos( l2478, i2479 )
        TSCP  l2478, i2479;
{
        TSCP  X5, X4, X3, X2, X1;

        PUSHSTACKTRACE( t4266 );
        if  ( EQ( TSCPTAG( l2478 ), PAIRTAG ) )  goto L4269;
        scrt1__24__car_2derror( l2478 );
L4269:
        X2 = PAIR_CAR( l2478 );
        if  ( NEQ( _S2CUINT( X2 ), _S2CUINT( c2354 ) ) )  goto L4272;
        X1 = scrt1_caddr( l2478 );
        goto L4275;
L4272:
        if  ( NEQ( _S2CUINT( X2 ), _S2CUINT( c2185 ) ) )  goto L4274;
        X3 = PAIR_CDR( l2478 );
        if  ( EQ( TSCPTAG( X3 ), PAIRTAG ) )  goto L4278;
        scrt1__24__car_2derror( X3 );
L4278:
        X1 = PAIR_CAR( X3 );
        goto L4275;
L4274:
        X1 = FALSEVALUE;
L4275:
        X1 = CONS( X1, EMPTYLIST );
        if  ( FALSE( PAIR_CAR( X1 ) ) )  goto L4281;
        X2 = lap_resolve_2dlabel( PAIR_CAR( X1 ) );
        SETGEN( PAIR_CAR( X1 ), X2 );
        X5 = SYMBOL_VALUE( id_2dgotos_v );
        X5 = UNKNOWNCALL( X5, 1 );
        X4 = VIA( PROCEDURE_CODE( X5 ) )( PAIR_CAR( X1 ), 
                                          PROCEDURE_CLOSURE( X5 ) );
        if  ( BITAND( BITOR( _S2CINT( X4 ), 
                             _S2CINT( i2479 ) ), 
                      3 ) )  goto L4285;
        X3 = _TSCP( IPLUS( _S2CINT( X4 ), _S2CINT( i2479 ) ) );
        goto L4286;
L4285:
        X3 = scrt2__2b_2dtwo( X4, i2479 );
L4286:
        X2 = SYMBOL_VALUE( set_2did_2dgotos_21_v );
        X2 = UNKNOWNCALL( X2, 2 );
        POPSTACKTRACE( VIA( PROCEDURE_CODE( X2 ) )( PAIR_CAR( X1 ), 
                                                    X3, 
                                                    PROCEDURE_CLOSURE( X2 ) ) );
L4281:
        POPSTACKTRACE( FALSEVALUE );
}

DEFTSCP( lap_save_2dcurrent_2dlap_v );
DEFCSTRING( t4287, "SAVE-CURRENT-LAP" );
EXTERNTSCP( lap_lap_2dtemps_2dused_v );
EXTERNTSCP( lap_lap_2dtemps_2dfree_v );
EXTERNTSCP( lap_lap_2dmax_2ddisplay_v );

TSCP  lap_save_2dcurrent_2dlap( l2513 )
        TSCP  l2513;
{
        TSCP  X5, X4, X3, X2, X1;

        PUSHSTACKTRACE( t4287 );
        X5 = sc_cons( lap_lap_2dmax_2ddisplay_v, EMPTYLIST );
        X4 = sc_cons( lap_lap_2dtemps_2dfree_v, X5 );
        X3 = sc_cons( lap_lap_2dtemps_2dused_v, X4 );
        X2 = sc_cons( lap_lap_2dcode_v, X3 );
        X1 = X2;
        if  ( FALSE( l2513 ) )  goto L4291;
        lap_lap_2dcode_v = scrt1_list_2dref( l2513, _TSCP( 0 ) );
        lap_lap_2dtemps_2dused_v = scrt1_list_2dref( l2513, _TSCP( 4 ) );
        lap_lap_2dtemps_2dfree_v = scrt1_list_2dref( l2513, _TSCP( 8 ) );
        lap_lap_2dmax_2ddisplay_v = scrt1_list_2dref( l2513, 
                                                      _TSCP( 12 ) );
        goto L4292;
L4291:
        lap_lap_2dcode_v = EMPTYLIST;
        lap_lap_2dtemps_2dused_v = EMPTYLIST;
        lap_lap_2dtemps_2dfree_v = c2518;
        lap_lap_2dmax_2ddisplay_v = SYMBOL_VALUE( free_2ddisplay_v );
L4292:
        POPSTACKTRACE( X1 );
}

DEFTSCP( lap_lap_2dtemps_2dused_v );
DEFCSTRING( t4295, "LAP-TEMPS-USED" );
DEFTSCP( lap_lap_2dtemps_2dfree_v );
DEFCSTRING( t4296, "LAP-TEMPS-FREE" );
DEFTSCP( lap_lap_2dmax_2ddisplay_v );
DEFCSTRING( t4297, "LAP-MAX-DISPLAY" );
DEFTSCP( lap_use_2dlap_2dtemp_v );
DEFCSTRING( t4298, "USE-LAP-TEMP" );

TSCP  lap_use_2dlap_2dtemp(  )
{
        TSCP  X2, X1;

        PUSHSTACKTRACE( t4298 );
        if  ( NEQ( _S2CUINT( lap_lap_2dtemps_2dfree_v ), 
                   _S2CUINT( EMPTYLIST ) ) )  goto L4300;
        X1 = SYMBOL_VALUE( report_2derror_v );
        X1 = UNKNOWNCALL( X1, 1 );
        VIA( PROCEDURE_CODE( X1 ) )( c2545, 
                                     PROCEDURE_CLOSURE( X1 ) );
        POPSTACKTRACE( c2546 );
L4300:
        X2 = lap_lap_2dtemps_2dfree_v;
        if  ( EQ( TSCPTAG( X2 ), PAIRTAG ) )  goto L4304;
        scrt1__24__car_2derror( X2 );
L4304:
        X1 = PAIR_CAR( X2 );
        if  ( TRUE( scrt1_memq( X1, lap_lap_2dtemps_2dused_v ) )
            )  goto L4307;
        lap_lap_2dtemps_2dused_v = sc_cons( X1, 
                                            lap_lap_2dtemps_2dused_v );
L4307:
        X2 = lap_lap_2dtemps_2dfree_v;
        if  ( EQ( TSCPTAG( X2 ), PAIRTAG ) )  goto L4310;
        scrt1__24__cdr_2derror( X2 );
L4310:
        lap_lap_2dtemps_2dfree_v = PAIR_CDR( X2 );
        POPSTACKTRACE( X1 );
}

DEFTSCP( lap_drop_2dlap_2dtemp_v );
DEFCSTRING( t4312, "DROP-LAP-TEMP" );

TSCP  lap_drop_2dlap_2dtemp( t2549 )
        TSCP  t2549;
{
        PUSHSTACKTRACE( t4312 );
        POPSTACKTRACE( SET( lap_lap_2dtemps_2dfree_v, 
                            sc_cons( t2549, lap_lap_2dtemps_2dfree_v ) ) );
}

DEFTSCP( lap_save_2dlap_2dtemps_v );
DEFCSTRING( t4314, "SAVE-LAP-TEMPS" );

TSCP  lap_save_2dlap_2dtemps(  )
{
        PUSHSTACKTRACE( t4314 );
        POPSTACKTRACE( lap_lap_2dtemps_2dfree_v );
}

DEFTSCP( lap_restore_2dlap_2dtemps_v );
DEFCSTRING( t4316, "RESTORE-LAP-TEMPS" );

TSCP  lap_restore_2dlap_2dtemps( s2554 )
        TSCP  s2554;
{
        PUSHSTACKTRACE( t4316 );
        POPSTACKTRACE( SET( lap_lap_2dtemps_2dfree_v, s2554 ) );
}

DEFTSCP( lap_done_2dlap_2dlap_v );
DEFCSTRING( t4318, "DONE-LAP-LAP" );
DEFTSCP( lap_done_2dlap_v );
DEFCSTRING( t4319, "DONE-LAP" );
EXTERNTSCPP( lap_done_2dlap, XAL1( TSCP ) );
EXTERNTSCP( lap_done_2dlap_v );
EXTERNTSCPP( scrt1_reverse, XAL1( TSCP ) );
EXTERNTSCP( scrt1_reverse_v );
EXTERNTSCPP( lap_pplap, 
             XAL4( TSCP, TSCP, TSCP, TSCP ) );
EXTERNTSCP( lap_pplap_v );
EXTERNTSCPP( scrt1_cadddr, XAL1( TSCP ) );
EXTERNTSCP( scrt1_cadddr_v );

TSCP  lap_done_2dlap( l2558 )
        TSCP  l2558;
{
        TSCP  X5, X4, X3, X2, X1;

        PUSHSTACKTRACE( t4319 );
        if  ( FALSE( lap_global_2dlap_2dcode_v ) )  goto L4321;
        X5 = sc_cons( EMPTYLIST, EMPTYLIST );
        X4 = sc_cons( EMPTYLIST, X5 );
        X3 = sc_cons( EMPTYLIST, X4 );
        X2 = sc_cons( lap_global_2dlap_2dcode_v, X3 );
        X1 = X2;
        lap_global_2dlap_2dcode_v = EMPTYLIST;
        lap_done_2dlap( X1 );
L4321:
        X1 = SYMBOL_VALUE( log_3f_v );
        X1 = UNKNOWNCALL( X1, 1 );
        if  ( FALSE( VIA( PROCEDURE_CODE( X1 ) )( c2563, 
                                                  PROCEDURE_CLOSURE( X1 ) ) )
            )  goto L4325;
        X1 = SYMBOL_VALUE( sc_2dicode_v );
        scrt6_format( X1, CONS( c2020, EMPTYLIST ) );
        if  ( EQ( TSCPTAG( l2558 ), PAIRTAG ) )  goto L4329;
        scrt1__24__car_2derror( l2558 );
L4329:
        X3 = PAIR_CAR( l2558 );
        X2 = scrt1_reverse( X3 );
        X3 = SYMBOL_VALUE( sc_2dicode_v );
        X1 = SYMBOL_VALUE( pretty_2dprint_2d_24tree_v );
        X1 = UNKNOWNCALL( X1, 2 );
        VIA( PROCEDURE_CODE( X1 ) )( X2, 
                                     X3, PROCEDURE_CLOSURE( X1 ) );
        X1 = SYMBOL_VALUE( sc_2dicode_v );
        scrt6_format( X1, CONS( c2084, EMPTYLIST ) );
L4325:
        lap_done_2dlap_2dlap_v = l2558;
        if  ( EQ( TSCPTAG( l2558 ), PAIRTAG ) )  goto L4332;
        scrt1__24__car_2derror( l2558 );
L4332:
        X2 = PAIR_CAR( l2558 );
        X1 = scrt1_reverse( X2 );
        X3 = PAIR_CDR( l2558 );
        if  ( EQ( TSCPTAG( X3 ), PAIRTAG ) )  goto L4336;
        scrt1__24__car_2derror( X3 );
L4336:
        X2 = PAIR_CAR( X3 );
        X3 = scrt1_cadddr( l2558 );
        X4 = SYMBOL_VALUE( sc_2dicode_v );
        POPSTACKTRACE( lap_pplap( X1, X2, X3, X4 ) );
}

DEFTSCP( lap_resolve_2dlabel_v );
DEFCSTRING( t4338, "RESOLVE-LABEL" );

TSCP  lap_resolve_2dlabel( l2586 )
        TSCP  l2586;
{
        TSCP  X2, X1;

        PUSHSTACKTRACE( t4338 );
L4339:
        X2 = SYMBOL_VALUE( id_2dalias_v );
        X2 = UNKNOWNCALL( X2, 1 );
        X1 = VIA( PROCEDURE_CODE( X2 ) )( l2586, 
                                          PROCEDURE_CLOSURE( X2 ) );
        if  ( FALSE( X1 ) )  goto L4341;
        l2586 = X1;
        GOBACK( L4339 );
L4341:
        POPSTACKTRACE( l2586 );
}

DEFTSCP( lap_pplap_v );
DEFCSTRING( t4343, "PPLAP" );
EXTERNTSCP( sc_emptystring );
EXTERNTSCPP( scrt6_newline, XAL1( TSCP ) );
EXTERNTSCP( scrt6_newline_v );
EXTERNTSCP( lap_pplap_2dtos_v );
EXTERNTSCPP( scrt6_display, XAL2( TSCP, TSCP ) );
EXTERNTSCP( scrt6_display_v );
EXTERNTSCPP( lap_pplap_2dcall, XAL2( TSCP, TSCP ) );
EXTERNTSCP( lap_pplap_2dcall_v );
EXTERNTSCPP( scrt2_zero_3f, XAL1( TSCP ) );
EXTERNTSCP( scrt2_zero_3f_v );
EXTERNTSCPP( sc_make_2dstring, XAL2( TSCP, TSCP ) );
EXTERNTSCP( sc_make_2dstring_v );
EXTERNTSCPP( lap_pplap_2dcomma_2dlist, XAL2( TSCP, TSCP ) );
EXTERNTSCP( lap_pplap_2dcomma_2dlist_v );
EXTERNTSCPP( scdebug_error, XAL3( TSCP, TSCP, TSCP ) );
EXTERNTSCP( scdebug_error_v );
EXTERNTSCPP( scrt2__3c_2dtwo, XAL2( TSCP, TSCP ) );
EXTERNTSCP( scrt2__3c_2dtwo_v );
EXTERNTSCPP( scrt2__3d_2dtwo, XAL2( TSCP, TSCP ) );
EXTERNTSCP( scrt2__3d_2dtwo_v );
EXTERNTSCPP( scrt6_write_2dwidth, XAL1( TSCP ) );
EXTERNTSCP( scrt6_write_2dwidth_v );
EXTERNTSCPP( scrt6_write_2dcount, XAL1( TSCP ) );
EXTERNTSCP( scrt6_write_2dcount_v );
EXTERNTSCPP( lap_subst_2dtos, XAL1( TSCP ) );
EXTERNTSCP( lap_subst_2dtos_v );

TSCP  lap_pplap( l2593, t2594, l2595, p2596 )
        TSCP  l2593, t2594, l2595, p2596;
{
        TSCP  X18, 
              X17, 
              X16, 
              X15, 
              X14, 
              X13, 
              X12, 
              X11, 
              X10, 
              X9, 
              X8, X7, X6, X5, X4, X3, X2, X1;

        PUSHSTACKTRACE( t4343 );
        X1 = EMPTYLIST;
        X2 = FALSEVALUE;
        X3 = sc_emptystring;
        X3 = CONS( X3, EMPTYLIST );
        X2 = CONS( X2, EMPTYLIST );
        X1 = CONS( X1, EMPTYLIST );
        scrt6_newline( CONS( p2596, EMPTYLIST ) );
        lap_pplap_2dtos_v = FALSEVALUE;
        X4 = l2593;
L4348:
        if  ( EQ( _S2CUINT( X4 ), _S2CUINT( EMPTYLIST ) ) )  goto L4349;
        if  ( EQ( TSCPTAG( X4 ), PAIRTAG ) )  goto L4353;
        scrt1__24__car_2derror( X4 );
L4353:
        X5 = PAIR_CAR( X4 );
        if  ( EQ( TSCPTAG( X5 ), PAIRTAG ) )  goto L4357;
        scrt1__24__car_2derror( X5 );
L4357:
        X9 = PAIR_CAR( X5 );
        if  ( NEQ( _S2CUINT( X9 ), _S2CUINT( c2637 ) ) )  goto L4360;
        scrt6_display( PAIR_CAR( X3 ), 
                       CONS( p2596, EMPTYLIST ) );
        X10 = PAIR_CDR( X5 );
        X11 = X10;
L4366:
        if  ( EQ( _S2CUINT( X11 ), _S2CUINT( EMPTYLIST ) ) )  goto L4367;
        if  ( EQ( TSCPTAG( X11 ), PAIRTAG ) )  goto L4371;
        scrt1__24__car_2derror( X11 );
L4371:
        X12 = PAIR_CAR( X11 );
        if  ( NEQ( TSCPTAG( X12 ), PAIRTAG ) )  goto L4374;
        lap_pplap_2dcall( X12, p2596 );
        goto L4375;
L4374:
        scrt6_display( X12, CONS( p2596, EMPTYLIST ) );
L4375:
        X11 = PAIR_CDR( X11 );
        GOBACK( L4366 );
L4367:
        scrt6_newline( CONS( p2596, EMPTYLIST ) );
        goto L4559;
L4360:
        if  ( NEQ( _S2CUINT( X9 ), _S2CUINT( c2100 ) ) )  goto L4377;
        X11 = PAIR_CDR( X5 );
        if  ( EQ( TSCPTAG( X11 ), PAIRTAG ) )  goto L4381;
        scrt1__24__car_2derror( X11 );
L4381:
        X10 = PAIR_CAR( X11 );
        X8 = lap_resolve_2dlabel( X10 );
        X11 = PAIR_CDR( X5 );
        if  ( EQ( TSCPTAG( X11 ), PAIRTAG ) )  goto L4388;
        scrt1__24__car_2derror( X11 );
L4388:
        X10 = PAIR_CAR( X11 );
        if  ( NEQ( _S2CUINT( X8 ), _S2CUINT( X10 ) ) )  goto L4559;
        X11 = SYMBOL_VALUE( id_2dgotos_v );
        X11 = UNKNOWNCALL( X11, 1 );
        X10 = VIA( PROCEDURE_CODE( X11 ) )( X8, 
                                            PROCEDURE_CLOSURE( X11 ) );
        if  ( NEQ( TSCPTAG( X10 ), FIXNUMTAG ) )  goto L4392;
        if  ( NEQ( _S2CUINT( X10 ), _S2CUINT( _TSCP( 0 ) ) ) )  goto L4396;
        goto L4559;
L4392:
        if  ( FALSE( scrt2_zero_3f( X10 ) ) )  goto L4396;
        goto L4559;
L4377:
        if  ( NEQ( _S2CUINT( X9 ), _S2CUINT( c2644 ) ) )  goto L4399;
        X12 = PAIR_CDR( X5 );
        if  ( EQ( TSCPTAG( X12 ), PAIRTAG ) )  goto L4403;
        scrt1__24__car_2derror( X12 );
L4403:
        X11 = PAIR_CAR( X12 );
        X10 = sc_make_2dstring( X11, 
                                CONS( _TSCP( 8210 ), EMPTYLIST ) );
        SETGEN( PAIR_CAR( X3 ), X10 );
        goto L4559;
L4399:
        if  ( NEQ( _S2CUINT( X9 ), _S2CUINT( c2648 ) ) )  goto L4405;
        scrt6_display( c2872, CONS( p2596, EMPTYLIST ) );
        X10 = PAIR_CDR( X5 );
        lap_pplap_2dcall( X10, p2596 );
        scrt6_newline( CONS( p2596, EMPTYLIST ) );
        X10 = PAIR_CDR( X5 );
        if  ( EQ( TSCPTAG( X10 ), PAIRTAG ) )  goto L4411;
        scrt1__24__cdr_2derror( X10 );
L4411:
        if  ( FALSE( PAIR_CDR( X10 ) ) )  goto L4559;
        scrt6_display( c2888, CONS( p2596, EMPTYLIST ) );
        X12 = PAIR_CDR( X5 );
        if  ( EQ( TSCPTAG( X12 ), PAIRTAG ) )  goto L4418;
        scrt1__24__cdr_2derror( X12 );
L4418:
        X11 = PAIR_CDR( X12 );
        lap_pplap_2dcomma_2dlist( X11, p2596 );
        scrt6_display( c2899, CONS( p2596, EMPTYLIST ) );
        scrt6_newline( CONS( p2596, EMPTYLIST ) );
        goto L4559;
L4405:
        if  ( NEQ( _S2CUINT( X9 ), _S2CUINT( c2652 ) ) )  goto L4420;
        if  ( FALSE( t2594 ) )  goto L4423;
        X10 = CONS( PAIR_CAR( X3 ), EMPTYLIST );
        scrt6_format( p2596, CONS( c2783, X10 ) );
        X11 = SYMBOL_VALUE( vname_v );
        X12 = t2594;
        X13 = EMPTYLIST;
        X14 = EMPTYLIST;
L4428:
        if  ( NEQ( _S2CUINT( X12 ), _S2CUINT( EMPTYLIST ) ) )  goto L4429;
        X10 = X13;
        goto L4436;
L4429:
        if  ( EQ( TSCPTAG( X12 ), PAIRTAG ) )  goto L4432;
        scrt1__24__car_2derror( X12 );
L4432:
        X18 = PAIR_CAR( X12 );
        X17 = X11;
        X17 = UNKNOWNCALL( X17, 1 );
        X16 = VIA( PROCEDURE_CODE( X17 ) )( X18, 
                                            PROCEDURE_CLOSURE( X17 ) );
        X15 = sc_cons( X16, EMPTYLIST );
        if  ( NEQ( _S2CUINT( X13 ), _S2CUINT( EMPTYLIST ) ) )  goto L4435;
        X16 = PAIR_CDR( X12 );
        X14 = X15;
        X13 = X15;
        X12 = X16;
        GOBACK( L4428 );
L4435:
        X16 = PAIR_CDR( X12 );
        if  ( EQ( TSCPTAG( X14 ), PAIRTAG ) )  goto L4440;
        scdebug_error( c2819, 
                       c2820, CONS( X14, EMPTYLIST ) );
L4440:
        X14 = SETGEN( PAIR_CDR( X14 ), X15 );
        X12 = X16;
        GOBACK( L4428 );
L4436:
        lap_pplap_2dcomma_2dlist( X10, p2596 );
        scrt6_format( p2596, CONS( c2664, EMPTYLIST ) );
L4423:
        if  ( FALSE( PAIR_CDR( X5 ) ) )  goto L4468;
        X10 = scrt1_caddr( X5 );
        X11 = X10;
L4447:
        if  ( BITAND( BITOR( _S2CINT( X11 ), 
                             _S2CINT( l2595 ) ), 
                      3 ) )  goto L4449;
        if  ( LT( _S2CINT( X11 ), _S2CINT( l2595 ) ) )  goto L4453;
        goto L4456;
L4449:
        if  ( FALSE( scrt2__3c_2dtwo( X11, l2595 ) ) )  goto L4456;
L4453:
        X12 = CONS( X11, EMPTYLIST );
        X12 = CONS( X11, X12 );
        X12 = CONS( PAIR_CAR( X3 ), X12 );
        scrt6_format( p2596, CONS( c2849, X12 ) );
        if  ( BITAND( BITOR( _S2CINT( X11 ), 
                             _S2CINT( _TSCP( 4 ) ) ), 
                      3 ) )  goto L4458;
        X11 = _TSCP( IPLUS( _S2CINT( X11 ), 
                            _S2CINT( _TSCP( 4 ) ) ) );
        GOBACK( L4447 );
L4458:
        X11 = scrt2__2b_2dtwo( X11, _TSCP( 4 ) );
        GOBACK( L4447 );
L4456:
        if  ( BITAND( BITOR( _S2CINT( X10 ), 
                             _S2CINT( l2595 ) ), 
                      3 ) )  goto L4461;
        if  ( NEQ( _S2CUINT( X10 ), _S2CUINT( l2595 ) ) )  goto L4465;
        goto L4468;
L4461:
        if  ( TRUE( scrt2__3d_2dtwo( X10, l2595 ) ) )  goto L4468;
L4465:
        X11 = X10;
        SETGEN( PAIR_CAR( X2 ), X11 );
        X11 = CONS( PAIR_CAR( X3 ), EMPTYLIST );
        scrt6_format( p2596, CONS( c2866, X11 ) );
L4468:
        if  ( TRUE( t2594 ) )  goto L4473;
        if  ( TRUE( PAIR_CAR( X2 ) ) )  goto L4473;
        goto L4559;
L4420:
        if  ( NEQ( _S2CUINT( X9 ), _S2CUINT( c2185 ) ) )  goto L4476;
        X11 = PAIR_CDR( X5 );
        if  ( EQ( TSCPTAG( X11 ), PAIRTAG ) )  goto L4480;
        scrt1__24__car_2derror( X11 );
L4480:
        X10 = PAIR_CAR( X11 );
        X7 = lap_resolve_2dlabel( X10 );
        X6 = PAIR_CAR( X3 );
        goto L4482;
L4476:
        if  ( NEQ( _S2CUINT( X9 ), _S2CUINT( c2354 ) ) )  goto L4483;
        X10 = CONS( PAIR_CAR( X3 ), EMPTYLIST );
        scrt6_format( p2596, CONS( c2745, X10 ) );
        X11 = PAIR_CDR( X5 );
        if  ( EQ( TSCPTAG( X11 ), PAIRTAG ) )  goto L4488;
        scrt1__24__car_2derror( X11 );
L4488:
        X10 = PAIR_CAR( X11 );
        lap_pplap_2dcall( X10, p2596 );
        X11 = scrt6_write_2dwidth( CONS( p2596, EMPTYLIST ) );
        X12 = scrt6_write_2dcount( CONS( p2596, EMPTYLIST ) );
        if  ( BITAND( BITOR( _S2CINT( X11 ), 
                             _S2CINT( X12 ) ), 
                      3 ) )  goto L4491;
        X10 = _TSCP( IDIFFERENCE( _S2CINT( X11 ), 
                                  _S2CINT( X12 ) ) );
        goto L4492;
L4491:
        X10 = scrt2__2d_2dtwo( X11, X12 );
L4492:
        if  ( BITAND( BITOR( _S2CINT( X10 ), 
                             _S2CINT( _TSCP( 80 ) ) ), 
                      3 ) )  goto L4495;
        if  ( LT( _S2CINT( X10 ), _S2CINT( _TSCP( 80 ) ) ) )  goto L4499;
        goto L4502;
L4495:
        if  ( FALSE( scrt2__3c_2dtwo( X10, _TSCP( 80 ) ) ) )  goto L4502;
L4499:
        X11 = CONS( PAIR_CAR( X3 ), EMPTYLIST );
        scrt6_format( p2596, CONS( c2769, X11 ) );
L4502:
        X10 = scrt1_caddr( X5 );
        X7 = lap_resolve_2dlabel( X10 );
        X6 = c2770;
        goto L4482;
L4483:
        if  ( NEQ( _S2CUINT( X9 ), _S2CUINT( c2111 ) ) )  goto L4503;
        X11 = PAIR_CDR( X5 );
        if  ( EQ( TSCPTAG( X11 ), PAIRTAG ) )  goto L4507;
        scrt1__24__car_2derror( X11 );
L4507:
        X10 = PAIR_CAR( X11 );
        if  ( NEQ( _S2CUINT( X10 ), _S2CUINT( c2132 ) ) )  goto L4510;
        scrt6_display( PAIR_CAR( X3 ), 
                       CONS( p2596, EMPTYLIST ) );
        X11 = scrt1_caddr( X5 );
        lap_pplap_2dcall( X11, p2596 );
        scrt6_format( p2596, CONS( c2664, EMPTYLIST ) );
        goto L4559;
L4510:
        if  ( NEQ( _S2CUINT( X10 ), _S2CUINT( c2143 ) ) )  goto L4513;
        X12 = scrt1_caddr( X5 );
        X11 = lap_subst_2dtos( X12 );
        if  ( FALSE( lap_pplap_2dtos_v ) )  goto L4516;
        X12 = SYMBOL_VALUE( report_2derror_v );
        X12 = UNKNOWNCALL( X12, 1 );
        VIA( PROCEDURE_CODE( X12 ) )( c2731, 
                                      PROCEDURE_CLOSURE( X12 ) );
L4516:
        lap_pplap_2dtos_v = X11;
        goto L4559;
L4513:
        if  ( NEQ( _S2CUINT( X10 ), _S2CUINT( c2207 ) ) )  goto L4518;
        if  ( FALSE( PAIR_CAR( X2 ) ) )  goto L4538;
        X11 = scrt1_caddr( X5 );
        if  ( TRUE( scrt1_equal_3f( X11, c2690 ) ) )  goto L4524;
        X11 = CONS( PAIR_CAR( X3 ), EMPTYLIST );
        scrt6_format( p2596, CONS( c2692, X11 ) );
        X11 = scrt1_caddr( X5 );
        lap_pplap_2dcall( X11, p2596 );
        scrt6_format( p2596, CONS( c2664, EMPTYLIST ) );
L4524:
        X11 = PAIR_CAR( X2 );
        X12 = X11;
L4529:
        if  ( BITAND( BITOR( _S2CINT( X12 ), 
                             _S2CINT( l2595 ) ), 
                      3 ) )  goto L4531;
        if  ( LT( _S2CINT( X12 ), _S2CINT( l2595 ) ) )  goto L4535;
        goto L4538;
L4531:
        if  ( FALSE( scrt2__3c_2dtwo( X12, l2595 ) ) )  goto L4538;
L4535:
        X13 = CONS( X12, EMPTYLIST );
        X13 = CONS( X12, X13 );
        X13 = CONS( PAIR_CAR( X3 ), X13 );
        scrt6_format( p2596, CONS( c2706, X13 ) );
        if  ( BITAND( BITOR( _S2CINT( X12 ), 
                             _S2CINT( _TSCP( 4 ) ) ), 
                      3 ) )  goto L4540;
        X12 = _TSCP( IPLUS( _S2CINT( X12 ), 
                            _S2CINT( _TSCP( 4 ) ) ) );
        GOBACK( L4529 );
L4540:
        X12 = scrt2__2b_2dtwo( X12, _TSCP( 4 ) );
        GOBACK( L4529 );
L4538:
        if  ( FALSE( PAIR_CAR( X2 ) ) )  goto L4542;
        X11 = c2728;
        goto L4543;
L4542:
        X12 = PAIR_CDR( X5 );
        if  ( EQ( TSCPTAG( X12 ), PAIRTAG ) )  goto L4546;
        scrt1__24__cdr_2derror( X12 );
L4546:
        X11 = PAIR_CDR( X12 );
L4543:
        scrt6_display( PAIR_CAR( X3 ), 
                       CONS( p2596, EMPTYLIST ) );
        X12 = scrt1_caddr( X5 );
        if  ( FALSE( scrt1_equal_3f( X12, c2690 ) ) )  goto L4549;
        scrt6_display( c2716, CONS( p2596, EMPTYLIST ) );
        goto L4552;
L4549:
        if  ( FALSE( SYMBOL_VALUE( sc_2dstack_2dtrace_v ) ) )  goto L4551;
        X12 = sc_cons( c2717, X11 );
        lap_pplap_2dcall( X12, p2596 );
        goto L4552;
L4551:
        X12 = sc_cons( c2716, X11 );
        lap_pplap_2dcall( X12, p2596 );
L4552:
        scrt6_format( p2596, CONS( c2664, EMPTYLIST ) );
        goto L4559;
L4518:
        scrt6_display( PAIR_CAR( X3 ), 
                       CONS( p2596, EMPTYLIST ) );
        X12 = PAIR_CDR( X5 );
        if  ( EQ( TSCPTAG( X12 ), PAIRTAG ) )  goto L4556;
        scrt1__24__car_2derror( X12 );
L4556:
        X11 = PAIR_CAR( X12 );
        lap_pplap_2dcall( X11, p2596 );
        scrt6_display( c2687, CONS( p2596, EMPTYLIST ) );
        X11 = scrt1_caddr( X5 );
        lap_pplap_2dcall( X11, p2596 );
        scrt6_format( p2596, CONS( c2664, EMPTYLIST ) );
        goto L4559;
L4503:
        scrt6_display( PAIR_CAR( X3 ), 
                       CONS( p2596, EMPTYLIST ) );
        lap_pplap_2dcall( X5, p2596 );
        scrt6_format( p2596, CONS( c2664, EMPTYLIST ) );
        goto L4559;
L4482:
        if  ( FALSE( scrt1_memq( X7, PAIR_CAR( X1 ) ) ) )  goto L4560;
        X9 = CONS( X7, EMPTYLIST );
        X9 = CONS( X6, X9 );
        scrt6_format( p2596, CONS( c2607, X9 ) );
        goto L4559;
L4560:
        X9 = CONS( X7, EMPTYLIST );
        X9 = CONS( X6, X9 );
        scrt6_format( p2596, CONS( c2606, X9 ) );
        goto L4559;
L4396:
        X9 = sc_cons( X8, PAIR_CAR( X1 ) );
        SETGEN( PAIR_CAR( X1 ), X9 );
        X9 = CONS( X8, EMPTYLIST );
        scrt6_format( p2596, CONS( c2940, X9 ) );
        goto L4559;
L4473:
        scrt6_newline( CONS( p2596, EMPTYLIST ) );
L4559:
        X4 = PAIR_CDR( X4 );
        GOBACK( L4348 );
L4349:
        POPSTACKTRACE( FALSEVALUE );
}

DEFTSCP( lap_pplap_2dtos_v );
DEFCSTRING( t4564, "PPLAP-TOS" );
DEFTSCP( lap_pop_2dtos_v );
DEFCSTRING( t4565, "POP-TOS" );

TSCP  lap_pop_2dtos(  )
{
        TSCP  X2, X1;

        PUSHSTACKTRACE( t4565 );
        X1 = lap_pplap_2dtos_v;
        lap_pplap_2dtos_v = FALSEVALUE;
        if  ( TRUE( X1 ) )  goto L4568;
        X2 = SYMBOL_VALUE( report_2derror_v );
        X2 = UNKNOWNCALL( X2, 1 );
        POPSTACKTRACE( VIA( PROCEDURE_CODE( X2 ) )( c2989, 
                                                    PROCEDURE_CLOSURE( X2 ) ) );
L4568:
        POPSTACKTRACE( X1 );
}

DEFTSCP( lap_subst_2dtos_v );
DEFCSTRING( t4570, "SUBST-TOS" );

TSCP  lap_subst_2dtos( f2991 )
        TSCP  f2991;
{
        TSCP  X3, X2, X1;

        PUSHSTACKTRACE( t4570 );
        if  ( NEQ( _S2CUINT( f2991 ), _S2CUINT( c2143 ) ) )  goto L4572;
        POPSTACKTRACE( lap_pop_2dtos(  ) );
L4572:
        if  ( NEQ( TSCPTAG( f2991 ), PAIRTAG ) )  goto L4574;
        X2 = PAIR_CAR( f2991 );
        X1 = lap_subst_2dtos( X2 );
        X3 = PAIR_CDR( f2991 );
        X2 = lap_subst_2dtos( X3 );
        POPSTACKTRACE( sc_cons( X1, X2 ) );
L4574:
        POPSTACKTRACE( f2991 );
}

DEFTSCP( lap_pplap_2dcall_v );
DEFCSTRING( t4578, "PPLAP-CALL" );
EXTERNTSCPP( scrt3_string_2d_3elist, XAL1( TSCP ) );
EXTERNTSCP( scrt3_string_2d_3elist_v );
EXTERNTSCPP( scrt1_assq, XAL2( TSCP, TSCP ) );
EXTERNTSCP( scrt1_assq_v );
EXTERNTSCPP( scrt3_list_2d_3estring, XAL1( TSCP ) );
EXTERNTSCP( scrt3_list_2d_3estring_v );
EXTERNTSCPP( scrt2__3e_2dtwo, XAL2( TSCP, TSCP ) );
EXTERNTSCP( scrt2__3e_2dtwo_v );
EXTERNTSCPP( scrt1_cdadr, XAL1( TSCP ) );
EXTERNTSCP( scrt1_cdadr_v );

TSCP  lap_pplap_2dcall( l3006, p3007 )
        TSCP  l3006, p3007;
{
        TSCP  X8, X7, X6, X5, X4, X3, X2, X1;

        PUSHSTACKTRACE( t4578 );
L4579:
        X2 = scrt6_write_2dwidth( CONS( p3007, EMPTYLIST ) );
        if  ( BITAND( BITOR( _S2CINT( X2 ), 
                             _S2CINT( _TSCP( 20 ) ) ), 
                      3 ) )  goto L4581;
        X1 = _TSCP( IDIFFERENCE( _S2CINT( X2 ), 
                                 _S2CINT( _TSCP( 20 ) ) ) );
        goto L4582;
L4581:
        X1 = scrt2__2d_2dtwo( X2, _TSCP( 20 ) );
L4582:
        if  ( NEQ( TSCPTAG( l3006 ), PAIRTAG ) )  goto L4584;
        X2 = PAIR_CAR( l3006 );
        if  ( NEQ( _S2CUINT( X2 ), _S2CUINT( c3034 ) ) )  goto L4586;
        scrt6_display( _TSCP( 8722 ), 
                       CONS( p3007, EMPTYLIST ) );
        X4 = PAIR_CDR( l3006 );
        if  ( EQ( TSCPTAG( X4 ), PAIRTAG ) )  goto L4592;
        scrt1__24__car_2derror( X4 );
L4592:
        X3 = PAIR_CAR( X4 );
        X2 = scrt3_string_2d_3elist( X3 );
        X3 = X2;
L4596:
        if  ( EQ( _S2CUINT( X3 ), _S2CUINT( EMPTYLIST ) ) )  goto L4597;
        if  ( EQ( TSCPTAG( X3 ), PAIRTAG ) )  goto L4601;
        scrt1__24__car_2derror( X3 );
L4601:
        X4 = PAIR_CAR( X3 );
        X5 = scrt1_assq( X4, c3245 );
        if  ( FALSE( X5 ) )  goto L4605;
        scrt6_display( _TSCP( 23570 ), 
                       CONS( p3007, EMPTYLIST ) );
        if  ( EQ( TSCPTAG( X5 ), PAIRTAG ) )  goto L4609;
        scrt1__24__cdr_2derror( X5 );
L4609:
        X6 = PAIR_CDR( X5 );
        scrt6_display( X6, CONS( p3007, EMPTYLIST ) );
        goto L4624;
L4605:
        if  ( AND( EQ( TSCPIMMEDIATETAG( X4 ), CHARACTERTAG ), 
                   EQ( TSCPIMMEDIATETAG( _TSCP( 8210 ) ), 
                       CHARACTERTAG ) ) )  goto L4612;
        X7 = CONS( _TSCP( 8210 ), EMPTYLIST );
        scdebug_error( c3224, c3225, CONS( X4, X7 ) );
L4612:
        X6 = BOOLEAN( LT( _S2CINT( X4 ), 
                          _S2CINT( _TSCP( 8210 ) ) ) );
        if  ( TRUE( X6 ) )  goto L4618;
        if  ( AND( EQ( TSCPIMMEDIATETAG( X4 ), CHARACTERTAG ), 
                   EQ( TSCPIMMEDIATETAG( _TSCP( 32274 ) ), 
                       CHARACTERTAG ) ) )  goto L4620;
        X7 = CONS( _TSCP( 32274 ), EMPTYLIST );
        scdebug_error( c3233, c3225, CONS( X4, X7 ) );
L4620:
        if  ( GT( _S2CINT( X4 ), _S2CINT( _TSCP( 32274 ) ) ) )  goto L4618;
        scrt6_display( X4, CONS( p3007, EMPTYLIST ) );
        goto L4624;
L4618:
        scrt6_display( _TSCP( 23570 ), 
                       CONS( p3007, EMPTYLIST ) );
        X8 = SYMBOL_VALUE( char_2d_3edl_v );
        X8 = UNKNOWNCALL( X8, 3 );
        X7 = VIA( PROCEDURE_CODE( X8 ) )( X4, 
                                          _TSCP( 32 ), 
                                          _TSCP( 12 ), 
                                          PROCEDURE_CLOSURE( X8 ) );
        X6 = scrt3_list_2d_3estring( X7 );
        scrt6_display( X6, CONS( p3007, EMPTYLIST ) );
L4624:
        X5 = scrt6_write_2dcount( CONS( p3007, EMPTYLIST ) );
        if  ( BITAND( BITOR( _S2CINT( X5 ), _S2CINT( X1 ) ), 
                      3 ) )  goto L4628;
        if  ( GT( _S2CINT( X5 ), _S2CINT( X1 ) ) )  goto L4632;
        goto L4635;
L4628:
        if  ( FALSE( scrt2__3e_2dtwo( X5, X1 ) ) )  goto L4635;
L4632:
        scrt6_display( _TSCP( 23570 ), 
                       CONS( p3007, EMPTYLIST ) );
        scrt6_newline( CONS( p3007, EMPTYLIST ) );
L4635:
        X3 = PAIR_CDR( X3 );
        GOBACK( L4596 );
L4597:
        POPSTACKTRACE( scrt6_display( _TSCP( 8722 ), 
                                      CONS( p3007, EMPTYLIST ) ) );
L4586:
        X3 = PAIR_CAR( l3006 );
        X2 = scrt1_memq( X3, c3042 );
        if  ( FALSE( X2 ) )  goto L4651;
        X4 = PAIR_CDR( l3006 );
        if  ( EQ( TSCPTAG( X4 ), PAIRTAG ) )  goto L4647;
        scrt1__24__car_2derror( X4 );
L4647:
        X3 = PAIR_CAR( X4 );
        if  ( NEQ( _S2CUINT( X3 ), _S2CUINT( c2143 ) ) )  goto L4651;
        X5 = PAIR_CAR( l3006 );
        X7 = lap_pop_2dtos(  );
        X6 = sc_cons( X7, EMPTYLIST );
        X4 = sc_cons( X5, X6 );
        X3 = X4;
        l3006 = X3;
        GOBACK( L4579 );
L4584:
        if  ( NEQ( _S2CUINT( l3006 ), _S2CUINT( c2143 ) ) )  goto L4652;
        X2 = lap_pop_2dtos(  );
        l3006 = X2;
        GOBACK( L4579 );
L4652:
        X2 = BOOLEAN( AND( EQ( TSCPTAG( l3006 ), EXTENDEDTAG ), 
                           EQ( TSCP_EXTENDEDTAG( l3006 ), 
                               SYMBOLTAG ) ) );
        if  ( FALSE( X2 ) )  goto L4663;
        X3 = SYMBOL_VALUE( id_2duse_v );
        X3 = UNKNOWNCALL( X3, 1 );
        if  ( FALSE( VIA( PROCEDURE_CODE( X3 ) )( l3006, 
                                                  PROCEDURE_CLOSURE( X3 ) ) )
            )  goto L4663;
        X4 = SYMBOL_VALUE( vname_v );
        X4 = UNKNOWNCALL( X4, 1 );
        X3 = VIA( PROCEDURE_CODE( X4 ) )( l3006, 
                                          PROCEDURE_CLOSURE( X4 ) );
        if  ( EQ( _S2CUINT( X3 ), _S2CUINT( l3006 ) ) )  goto L4661;
        X3 = SYMBOL_VALUE( report_2derror_v );
        X3 = UNKNOWNCALL( X3, 2 );
        VIA( PROCEDURE_CODE( X3 ) )( c3026, 
                                     l3006, 
                                     PROCEDURE_CLOSURE( X3 ) );
L4661:
        X4 = SYMBOL_VALUE( vname_v );
        X4 = UNKNOWNCALL( X4, 1 );
        X3 = VIA( PROCEDURE_CODE( X4 ) )( l3006, 
                                          PROCEDURE_CLOSURE( X4 ) );
        POPSTACKTRACE( scrt6_display( X3, 
                                      CONS( p3007, EMPTYLIST ) ) );
L4651:
        X2 = PAIR_CAR( l3006 );
        X1 = BOOLEAN( EQ( _S2CUINT( X2 ), 
                          _S2CUINT( c2407 ) ) );
        if  ( FALSE( X1 ) )  goto L4691;
        X3 = PAIR_CDR( l3006 );
        if  ( EQ( TSCPTAG( X3 ), PAIRTAG ) )  goto L4673;
        scrt1__24__car_2derror( X3 );
L4673:
        X2 = PAIR_CAR( X3 );
        if  ( NEQ( TSCPTAG( X2 ), PAIRTAG ) )  goto L4691;
        X2 = scrt1_caadr( l3006 );
        X3 = scrt1_cdadr( l3006 );
        X4 = scrt1_assq( X2, c3181 );
        if  ( NEQ( _S2CUINT( X2 ), _S2CUINT( c2407 ) ) )  goto L4678;
        if  ( EQ( TSCPTAG( X3 ), PAIRTAG ) )  goto L4681;
        scrt1__24__car_2derror( X3 );
L4681:
        X5 = PAIR_CAR( X3 );
        l3006 = X5;
        GOBACK( L4579 );
L4678:
        if  ( FALSE( X4 ) )  goto L4683;
        if  ( EQ( TSCPTAG( X4 ), PAIRTAG ) )  goto L4686;
        scrt1__24__cdr_2derror( X4 );
L4686:
        X6 = PAIR_CDR( X4 );
        X5 = sc_cons( X6, X3 );
        l3006 = X5;
        GOBACK( L4579 );
L4683:
        X5 = CONS( PAIR_CAR( l3006 ), EMPTYLIST );
        scrt6_format( p3007, CONS( c3164, X5 ) );
        X5 = PAIR_CDR( l3006 );
        lap_pplap_2dcomma_2dlist( X5, p3007 );
        POPSTACKTRACE( scrt6_display( c3153, 
                                      CONS( p3007, EMPTYLIST ) ) );
L4691:
        X2 = PAIR_CAR( l3006 );
        X1 = BOOLEAN( EQ( _S2CUINT( X2 ), 
                          _S2CUINT( c3090 ) ) );
        if  ( FALSE( X1 ) )  goto L4707;
        X3 = PAIR_CDR( l3006 );
        if  ( EQ( TSCPTAG( X3 ), PAIRTAG ) )  goto L4702;
        scrt1__24__car_2derror( X3 );
L4702:
        X2 = PAIR_CAR( X3 );
        if  ( NEQ( TSCPTAG( X2 ), PAIRTAG ) )  goto L4707;
        X2 = scrt1_caadr( l3006 );
        if  ( NEQ( _S2CUINT( X2 ), _S2CUINT( c3111 ) ) )  goto L4707;
        X2 = scrt1_cadadr( l3006 );
        l3006 = X2;
        GOBACK( L4579 );
L4663:
        POPSTACKTRACE( scrt6_display( l3006, 
                                      CONS( p3007, EMPTYLIST ) ) );
L4707:
        X2 = PAIR_CAR( l3006 );
        X1 = BOOLEAN( EQ( _S2CUINT( X2 ), 
                          _S2CUINT( c3122 ) ) );
        if  ( FALSE( X1 ) )  goto L4723;
        X3 = PAIR_CDR( l3006 );
        if  ( EQ( TSCPTAG( X3 ), PAIRTAG ) )  goto L4718;
        scrt1__24__car_2derror( X3 );
L4718:
        X2 = PAIR_CAR( X3 );
        if  ( NEQ( TSCPTAG( X2 ), PAIRTAG ) )  goto L4723;
        X2 = scrt1_caadr( l3006 );
        if  ( NEQ( _S2CUINT( X2 ), _S2CUINT( c3111 ) ) )  goto L4723;
        X3 = CONS( EMPTYLIST, EMPTYLIST );
        X2 = scrt1_cons_2a( c2407, 
                            CONS( scrt1_cadadr( l3006 ), X3 ) );
        l3006 = X2;
        GOBACK( L4579 );
L4723:
        X1 = PAIR_CAR( l3006 );
        lap_pplap_2dcall( X1, p3007 );
        scrt6_display( c3148, CONS( p3007, EMPTYLIST ) );
        X1 = PAIR_CDR( l3006 );
        lap_pplap_2dcomma_2dlist( X1, p3007 );
        POPSTACKTRACE( scrt6_display( c3153, 
                                      CONS( p3007, EMPTYLIST ) ) );
}

DEFTSCP( lap_pplap_2dcomma_2dlist_v );
DEFCSTRING( t4727, "PPLAP-COMMA-LIST" );
EXTERNTSCPP( lap_pplap_2dsize, XAL2( TSCP, TSCP ) );
EXTERNTSCP( lap_pplap_2dsize_v );

TSCP  lap_pplap_2dcomma_2dlist( l3271, p3272 )
        TSCP  l3271, p3272;
{
        TSCP  X5, X4, X3, X2, X1;

        PUSHSTACKTRACE( t4727 );
L4728:
        X1 = scrt6_write_2dcount( CONS( p3272, EMPTYLIST ) );
        X5 = scrt6_write_2dwidth( CONS( p3272, EMPTYLIST ) );
        if  ( BITAND( BITOR( _S2CINT( X5 ), _S2CINT( X1 ) ), 
                      3 ) )  goto L4731;
        X4 = _TSCP( IDIFFERENCE( _S2CINT( X5 ), 
                                 _S2CINT( X1 ) ) );
        goto L4732;
L4731:
        X4 = scrt2__2d_2dtwo( X5, X1 );
L4732:
        X3 = lap_pplap_2dsize( l3271, X4 );
        if  ( NEQ( TSCPTAG( X3 ), FIXNUMTAG ) )  goto L4734;
        X2 = BOOLEAN( LT( _S2CINT( X3 ), 0 ) );
        goto L4735;
L4734:
        X2 = scrt2_negative_3f( X3 );
L4735:
        if  ( FALSE( l3271 ) )  goto L4737;
        if  ( EQ( TSCPTAG( l3271 ), PAIRTAG ) )  goto L4741;
        scrt1__24__car_2derror( l3271 );
L4741:
        X3 = PAIR_CAR( l3271 );
        lap_pplap_2dcall( X3, p3272 );
        if  ( FALSE( PAIR_CDR( l3271 ) ) )  goto L4744;
        scrt6_display( c3287, CONS( p3272, EMPTYLIST ) );
        if  ( FALSE( X2 ) )  goto L4747;
        scrt6_newline( CONS( p3272, EMPTYLIST ) );
        X3 = SYMBOL_VALUE( set_2dwrite_2dcount_21_v );
        X3 = UNKNOWNCALL( X3, 2 );
        VIA( PROCEDURE_CODE( X3 ) )( p3272, 
                                     X1, PROCEDURE_CLOSURE( X3 ) );
L4747:
        X3 = PAIR_CDR( l3271 );
        l3271 = X3;
        GOBACK( L4728 );
L4744:
        POPSTACKTRACE( FALSEVALUE );
L4737:
        POPSTACKTRACE( FALSEVALUE );
}

DEFTSCP( lap_pplap_2dsize_v );
DEFCSTRING( t4751, "PPLAP-SIZE" );

TSCP  lap_pplap_2dsize( l3308, l3309 )
        TSCP  l3308, l3309;
{
        TSCP  X4, X3, X2, X1;

        PUSHSTACKTRACE( t4751 );
L4752:
        if  ( NEQ( TSCPTAG( l3309 ), FIXNUMTAG ) )  goto L4754;
        if  ( GTE( _S2CINT( l3309 ), 0 ) )  goto L4758;
        POPSTACKTRACE( l3309 );
L4754:
        if  ( FALSE( scrt2_negative_3f( l3309 ) ) )  goto L4758;
        POPSTACKTRACE( l3309 );
L4758:
        if  ( EQ( _S2CUINT( l3308 ), _S2CUINT( EMPTYLIST ) ) )  goto L4761;
        if  ( NEQ( TSCPTAG( l3308 ), PAIRTAG ) )  goto L4763;
        X1 = PAIR_CAR( l3308 );
        if  ( NEQ( _S2CUINT( X1 ), _S2CUINT( c3034 ) ) )  goto L4765;
        X4 = PAIR_CDR( l3308 );
        if  ( EQ( TSCPTAG( X4 ), PAIRTAG ) )  goto L4770;
        scrt1__24__car_2derror( X4 );
L4770:
        X3 = PAIR_CAR( X4 );
        if  ( AND( EQ( TSCPTAG( X3 ), EXTENDEDTAG ), 
                   EQ( TSCP_EXTENDEDTAG( X3 ), STRINGTAG ) ) )  goto L4773;
        scdebug_error( c3336, 
                       c3337, CONS( X3, EMPTYLIST ) );
L4773:
        X2 = C_FIXED( STRING_LENGTH( X3 ) );
        if  ( BITAND( BITOR( _S2CINT( X2 ), 
                             _S2CINT( _TSCP( 20 ) ) ), 
                      3 ) )  goto L4776;
        X1 = _TSCP( IPLUS( _S2CINT( X2 ), 
                           _S2CINT( _TSCP( 20 ) ) ) );
        goto L4777;
L4776:
        X1 = scrt2__2b_2dtwo( X2, _TSCP( 20 ) );
L4777:
        if  ( BITAND( BITOR( _S2CINT( l3309 ), 
                             _S2CINT( X1 ) ), 
                      3 ) )  goto L4779;
        POPSTACKTRACE( _TSCP( IDIFFERENCE( _S2CINT( l3309 ), 
                                           _S2CINT( X1 ) ) ) );
L4779:
        POPSTACKTRACE( scrt2__2d_2dtwo( l3309, X1 ) );
L4765:
        X1 = PAIR_CDR( l3308 );
        X2 = PAIR_CAR( l3308 );
        if  ( BITAND( BITOR( _S2CINT( l3309 ), 
                             _S2CINT( _TSCP( 16 ) ) ), 
                      3 ) )  goto L4783;
        X3 = _TSCP( IDIFFERENCE( _S2CINT( l3309 ), 
                                 _S2CINT( _TSCP( 16 ) ) ) );
        goto L4784;
L4783:
        X3 = scrt2__2d_2dtwo( l3309, _TSCP( 16 ) );
L4784:
        l3309 = lap_pplap_2dsize( X2, X3 );
        l3308 = X1;
        GOBACK( L4752 );
L4763:
        if  ( NEQ( _S2CUINT( l3308 ), _S2CUINT( c2143 ) ) )  goto L4785;
        l3308 = lap_pplap_2dtos_v;
        GOBACK( L4752 );
L4785:
        if  ( NOT( AND( EQ( TSCPTAG( l3308 ), EXTENDEDTAG ), 
                        EQ( TSCP_EXTENDEDTAG( l3308 ), SYMBOLTAG ) ) )
            )  goto L4787;
        X4 = SYMBOL_VALUE( id_2duse_v );
        X4 = UNKNOWNCALL( X4, 1 );
        if  ( FALSE( VIA( PROCEDURE_CODE( X4 ) )( l3308, 
                                                  PROCEDURE_CLOSURE( X4 ) ) )
            )  goto L4789;
        X4 = SYMBOL_VALUE( vname_v );
        X4 = UNKNOWNCALL( X4, 1 );
        X3 = VIA( PROCEDURE_CODE( X4 ) )( l3308, 
                                          PROCEDURE_CLOSURE( X4 ) );
        goto L4788;
L4789:
        X3 = l3308;
        goto L4788;
L4787:
        X3 = l3308;
L4788:
        X2 = scrt6_format( c3338, CONS( X3, EMPTYLIST ) );
        if  ( AND( EQ( TSCPTAG( X2 ), EXTENDEDTAG ), 
                   EQ( TSCP_EXTENDEDTAG( X2 ), STRINGTAG ) ) )  goto L4792;
        scdebug_error( c3336, 
                       c3337, CONS( X2, EMPTYLIST ) );
L4792:
        X1 = C_FIXED( STRING_LENGTH( X2 ) );
        if  ( BITAND( BITOR( _S2CINT( l3309 ), 
                             _S2CINT( X1 ) ), 
                      3 ) )  goto L4795;
        POPSTACKTRACE( _TSCP( IDIFFERENCE( _S2CINT( l3309 ), 
                                           _S2CINT( X1 ) ) ) );
L4795:
        POPSTACKTRACE( scrt2__2d_2dtwo( l3309, X1 ) );
L4761:
        POPSTACKTRACE( l3309 );
}

DEFTSCP( lap_downshift_v );
DEFCSTRING( t4797, "DOWNSHIFT" );

TSCP  lap_downshift( o3395 )
        TSCP  o3395;
{
        TSCP  X2, X1;

        PUSHSTACKTRACE( t4797 );
        if  ( NOT( AND( EQ( TSCPTAG( o3395 ), EXTENDEDTAG ), 
                        EQ( TSCP_EXTENDEDTAG( o3395 ), SYMBOLTAG ) ) )
            )  goto L4799;
        X2 = SYMBOL_NAME( o3395 );
        X1 = SYMBOL_VALUE( string_2ddowncase_v );
        X1 = UNKNOWNCALL( X1, 1 );
        POPSTACKTRACE( VIA( PROCEDURE_CODE( X1 ) )( X2, 
                                                    PROCEDURE_CLOSURE( X1 ) ) );
L4799:
        POPSTACKTRACE( o3395 );
}

DEFTSCP( lap_load_2dplist_2dlap_v );
DEFCSTRING( t4802, "LOAD-PLIST-LAP" );

TSCP  lap_load_2dplist_2dlap(  )
{
        TSCP  X3, X2, X1;

        PUSHSTACKTRACE( t4802 );
        X1 = c3433;
L4805:
        if  ( EQ( _S2CUINT( X1 ), _S2CUINT( EMPTYLIST ) ) )  goto L4806;
        if  ( EQ( TSCPTAG( X1 ), PAIRTAG ) )  goto L4810;
        scrt1__24__car_2derror( X1 );
L4810:
        X2 = PAIR_CAR( X1 );
        X3 = SYMBOL_VALUE( set_2did_2dvname_21_v );
        X3 = UNKNOWNCALL( X3, 2 );
        VIA( PROCEDURE_CODE( X3 ) )( X2, 
                                     X2, PROCEDURE_CLOSURE( X3 ) );
        X3 = SYMBOL_VALUE( set_2did_2duse_21_v );
        X3 = UNKNOWNCALL( X3, 2 );
        VIA( PROCEDURE_CODE( X3 ) )( X2, 
                                     c3432, 
                                     PROCEDURE_CLOSURE( X3 ) );
        X1 = PAIR_CDR( X1 );
        GOBACK( L4805 );
L4806:
        POPSTACKTRACE( FALSEVALUE );
}

void scrt3__init();
void scdebug__init();
void scrt2__init();
void scrt6__init();
void scrt1__init();

static void  init_modules( compiler_version )
        char *compiler_version;
{
        scrt3__init();
        scdebug__init();
        scrt2__init();
        scrt6__init();
        scrt1__init();
        MAXDISPLAY( 0 );
}

void  lap__init()
{
        static int  init = 0;
        if  (init)  return;
        init = 1;
        INITHEAP( 0, 0, 0, 0 );
        init_constants();
        init_modules( "(lap SCHEME->C COMPILER 15mar93jfb)" );
        sc_segv__handlers();
        INITIALIZEVAR( t3954, 
                       ADR( lap_global_2dlap_2dcode_v ), 
                       EMPTYLIST );
        INITIALIZEVAR( t3955, 
                       ADR( lap_emit_2dglobal_2dlap_v ), 
                       MAKEPROCEDURE( 1, 
                                      0, 
                                      lap_emit_2dglobal_2dlap, 
                                      EMPTYLIST ) );
        INITIALIZEVAR( t3957, 
                       ADR( lap_lap_2dcode_v ), EMPTYLIST );
        INITIALIZEVAR( t3958, 
                       ADR( lap_emit_2dlap_v ), 
                       MAKEPROCEDURE( 1, 
                                      0, lap_emit_2dlap, EMPTYLIST ) );
        INITIALIZEVAR( t4011, 
                       ADR( lap_peep_2dlap_v ), 
                       MAKEPROCEDURE( 1, 
                                      0, lap_peep_2dlap, EMPTYLIST ) );
        INITIALIZEVAR( t4266, 
                       ADR( lap_bump_2dlabel_2dgotos_v ), 
                       MAKEPROCEDURE( 2, 
                                      0, 
                                      lap_bump_2dlabel_2dgotos, 
                                      EMPTYLIST ) );
        INITIALIZEVAR( t4287, 
                       ADR( lap_save_2dcurrent_2dlap_v ), 
                       MAKEPROCEDURE( 1, 
                                      0, 
                                      lap_save_2dcurrent_2dlap, 
                                      EMPTYLIST ) );
        INITIALIZEVAR( t4295, 
                       ADR( lap_lap_2dtemps_2dused_v ), 
                       EMPTYLIST );
        INITIALIZEVAR( t4296, 
                       ADR( lap_lap_2dtemps_2dfree_v ), 
                       EMPTYLIST );
        INITIALIZEVAR( t4297, 
                       ADR( lap_lap_2dmax_2ddisplay_v ), 
                       _TSCP( 0 ) );
        INITIALIZEVAR( t4298, 
                       ADR( lap_use_2dlap_2dtemp_v ), 
                       MAKEPROCEDURE( 0, 
                                      0, 
                                      lap_use_2dlap_2dtemp, EMPTYLIST ) );
        INITIALIZEVAR( t4312, 
                       ADR( lap_drop_2dlap_2dtemp_v ), 
                       MAKEPROCEDURE( 1, 
                                      0, 
                                      lap_drop_2dlap_2dtemp, EMPTYLIST ) );
        INITIALIZEVAR( t4314, 
                       ADR( lap_save_2dlap_2dtemps_v ), 
                       MAKEPROCEDURE( 0, 
                                      0, 
                                      lap_save_2dlap_2dtemps, 
                                      EMPTYLIST ) );
        INITIALIZEVAR( t4316, 
                       ADR( lap_restore_2dlap_2dtemps_v ), 
                       MAKEPROCEDURE( 1, 
                                      0, 
                                      lap_restore_2dlap_2dtemps, 
                                      EMPTYLIST ) );
        INITIALIZEVAR( t4318, 
                       ADR( lap_done_2dlap_2dlap_v ), EMPTYLIST );
        INITIALIZEVAR( t4319, 
                       ADR( lap_done_2dlap_v ), 
                       MAKEPROCEDURE( 1, 
                                      0, lap_done_2dlap, EMPTYLIST ) );
        INITIALIZEVAR( t4338, 
                       ADR( lap_resolve_2dlabel_v ), 
                       MAKEPROCEDURE( 1, 
                                      0, 
                                      lap_resolve_2dlabel, EMPTYLIST ) );
        INITIALIZEVAR( t4343, 
                       ADR( lap_pplap_v ), 
                       MAKEPROCEDURE( 4, 
                                      0, lap_pplap, EMPTYLIST ) );
        INITIALIZEVAR( t4564, 
                       ADR( lap_pplap_2dtos_v ), EMPTYLIST );
        INITIALIZEVAR( t4565, 
                       ADR( lap_pop_2dtos_v ), 
                       MAKEPROCEDURE( 0, 
                                      0, lap_pop_2dtos, EMPTYLIST ) );
        INITIALIZEVAR( t4570, 
                       ADR( lap_subst_2dtos_v ), 
                       MAKEPROCEDURE( 1, 
                                      0, 
                                      lap_subst_2dtos, EMPTYLIST ) );
        INITIALIZEVAR( t4578, 
                       ADR( lap_pplap_2dcall_v ), 
                       MAKEPROCEDURE( 2, 
                                      0, 
                                      lap_pplap_2dcall, EMPTYLIST ) );
        INITIALIZEVAR( t4727, 
                       ADR( lap_pplap_2dcomma_2dlist_v ), 
                       MAKEPROCEDURE( 2, 
                                      0, 
                                      lap_pplap_2dcomma_2dlist, 
                                      EMPTYLIST ) );
        INITIALIZEVAR( t4751, 
                       ADR( lap_pplap_2dsize_v ), 
                       MAKEPROCEDURE( 2, 
                                      0, 
                                      lap_pplap_2dsize, EMPTYLIST ) );
        INITIALIZEVAR( t4797, 
                       ADR( lap_downshift_v ), 
                       MAKEPROCEDURE( 1, 
                                      0, lap_downshift, EMPTYLIST ) );
        INITIALIZEVAR( t4802, 
                       ADR( lap_load_2dplist_2dlap_v ), 
                       MAKEPROCEDURE( 0, 
                                      0, 
                                      lap_load_2dplist_2dlap, 
                                      EMPTYLIST ) );
        return;
}
